@@ -12,8 +12,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from oslo_config import cfg
-
+from rally.common import cfg
 from rally.common import logging
 from rally.plugins.openstack.cfg import opts as openstack_opts
 from rally.task import engine
@@ -34,6 +33,13 @@ def list_opts():
     return merged_opts.items()
 
 
+def update_opt_defaults():
+    logging.oslogging.cfg.set_defaults(
+        logging.oslogging._options.generic_log_opts,
+        use_stderr=True
+    )
+
+
 _registered = False
 
 
