@@ -14,9 +14,7 @@
 #    under the License.
 
 import re
-
-from sphinx.util import docstrings
-
+import sys
 
 PARAM_OR_RETURNS_REGEX = re.compile(":(?:param|returns)")
 RETURNS_REGEX = re.compile(":returns: (?P<doc>.*)", re.S)
@@ -24,6 +22,40 @@ PARAM_REGEX = re.compile(":param (?P<name>[\*\w]+): (?P<doc>.*?)"
                          "(?:(?=:param)|(?=:return)|(?=:raises)|\Z)", re.S)
 
 
+def trim(docstring):
+    """trim function from PEP-257"""
+    if not docstring:
+        return ""
+    # Convert tabs to spaces (following the normal Python rules)
+    # and split into a list of lines:
+    lines = docstring.expandtabs().splitlines()
+    # Determine minimum indentation (first line doesn't count):
+    indent = sys.maxsize
+    for line in lines[1:]:
+        stripped = line.lstrip()
+        if stripped:
+            indent = min(indent, len(line) - len(stripped))
+    # Remove indentation (first line is special):
+    trimmed = [lines[0].strip()]
+    if indent < sys.maxsize:
+        for line in lines[1:]:
+            trimmed.append(line[indent:].rstrip())
+    # Strip off trailing and leading blank lines:
+    while trimmed and not trimmed[-1]:
+        trimmed.pop()
+    while trimmed and not trimmed[0]:
+        trimmed.pop(0)
+
+    # Current code/unittests expects a line return at
+    # end of multiline docstrings
+    # workaround expected behavior from unittests
+    if "\n" in docstring:
+        trimmed.append("")
+
+    # Return a single string:
+    return "\n".join(trimmed)
+
+
 def reindent(string):
     return "\n".join(l.strip() for l in string.strip().split("\n"))
 
@@ -44,7 +76,7 @@ def parse_docstring(docstring):
     params = []
 
     if docstring:
-        docstring = "\n".join(docstrings.prepare_docstring(docstring))
+        docstring = trim(docstring)
 
         lines = docstring.split("\n", 1)
         short_description = lines[0]
@@ -62,8 +94,7 @@ def parse_docstring(docstring):
 
             if params_returns_desc:
                 params = [
-                    {"name": name,
-                     "doc": "\n".join(docstrings.prepare_docstring(doc))}
+                    {"name": name, "doc": trim(doc)}
                     for name, doc in PARAM_REGEX.findall(params_returns_desc)
                 ]
 
@@ -92,13 +123,13 @@ class InfoMixin(object):
 
     @classmethod
     def get_info(cls):
-        plugin_ = getattr(cls, "func_ref", cls)
         doc = parse_docstring(cls._get_doc())
 
         return {
-            "name": plugin_.get_name(),
-            "namespace": plugin_.get_namespace(),
-            "module": plugin_.__module__,
+            "name": cls.get_name(),
+            "platform": cls.get_platform(),
+            "platform": cls.get_platform(),
+            "module": cls.__module__,
             "title": doc["short_description"],
             "description": doc["long_description"],
             "parameters": doc["params"],
