@@ -12,19 +12,19 @@
 
 import random
 
-from rally.common.i18n import _
 from rally.common import utils
+from rally.common import validation
 from rally import exceptions
 from rally.task import atomic
 from rally.task import scenario
-from rally.task import validation
 
 
 """Dummy scenarios for testing Rally engine at scale."""
 
 
 class DummyScenarioException(exceptions.RallyException):
-    msg_fmt = _("Dummy scenario expected exception: '%(message)s'")
+    error_code = 530
+    msg_fmt = "Dummy scenario expected exception: '%(message)s'"
 
 
 @scenario.configure(name="Dummy.failure")
@@ -45,12 +45,20 @@ class DummyFailure(scenario.Scenario):
         utils.interruptable_sleep(sleep)
         if from_iteration <= self.context["iteration"] <= to_iteration:
             if each and not self.context["iteration"] % each:
-                raise DummyScenarioException(_("Expected failure"))
+                raise DummyScenarioException("Expected failure")
 
 
 @scenario.configure(name="Dummy.dummy")
 class Dummy(scenario.Scenario):
 
+    @atomic.action_timer("bar")
+    def bar(self, sleep):
+        utils.interruptable_sleep(sleep)
+
+    @atomic.action_timer("foo")
+    def foo(self, sleep):
+        self.bar(sleep)
+
     def run(self, sleep=0):
         """Do nothing and sleep for the given number of seconds (0 by default).
 
@@ -60,20 +68,20 @@ class Dummy(scenario.Scenario):
 
         :param sleep: idle time of method (in seconds).
         """
-        utils.interruptable_sleep(sleep)
+        self.foo(sleep)
 
 
-@validation.number("size_of_message",
-                   minval=1, integer_only=True, nullable=True)
+@validation.add("number", param_name="size_of_message", minval=1,
+                integer_only=True, nullable=True)
 @scenario.configure(name="Dummy.dummy_exception")
 class DummyException(scenario.Scenario):
 
     def run(self, size_of_message=1, sleep=1, message=""):
-        """Throw an exception.
+        """Throws an exception.
 
-        Dummy.dummy_exception can be used for test if exceptions are processed
-        properly by ScenarioRunners and benchmark and analyze rally
-        results storing process.
+        Dummy.dummy_exception used for testing if exceptions are processed
+        properly by task engine and analyze rally results storing & displaying
+        capabilities.
 
         :param size_of_message: int size of the exception message
         :param sleep: idle time of method (in seconds).
@@ -86,17 +94,17 @@ class DummyException(scenario.Scenario):
         raise DummyScenarioException(message)
 
 
-@validation.number("exception_probability",
-                   minval=0, maxval=1, integer_only=False, nullable=True)
+@validation.add("number", param_name="exception_probability",
+                minval=0, maxval=1, integer_only=False, nullable=True)
 @scenario.configure(name="Dummy.dummy_exception_probability")
 class DummyExceptionProbability(scenario.Scenario):
 
     def run(self, exception_probability=0.5):
-        """Throw an exception with given probability.
+        """Throws an exception with given probability.
 
-        Dummy.dummy_exception_probability can be used to test if exceptions
-        are processed properly by ScenarioRunners. This scenario will throw
-        an exception sometimes, depending on the given exception probability.
+        Dummy.dummy_exception_probability used for testing if exceptions are
+        processed properly by task engine and analyze rally results storing
+        & displaying capabilities.
 
         :param exception_probability: Sets how likely it is that an exception
                                       will be thrown. Float between 0 and 1
@@ -190,8 +198,7 @@ class DummyOutput(scenario.Scenario):
 class DummyRandomFailInAtomic(scenario.Scenario):
     """Randomly throw exceptions in atomic actions."""
 
-    @atomic.action_timer("dummy_fail_test")
-    def _random_fail_emitter(self, exception_probability):
+    def _play_roulette(self, exception_probability):
         """Throw an exception with given probability.
 
         :raises KeyError: when exception_probability is bigger
@@ -208,14 +215,24 @@ class DummyRandomFailInAtomic(scenario.Scenario):
         :param exception_probability: Probability with which atomic actions
                                       fail in this dummy scenario (0 <= p <= 1)
         """
-        self._random_fail_emitter(exception_probability)
-        self._random_fail_emitter(exception_probability)
+        # devide probability on the number of possible places to fail
+        if exception_probability != 1:
+            exception_probability = exception_probability / 4.0
+        with atomic.ActionTimer(self, "dummy_fail_test"):
+            self._play_roulette(exception_probability)
+            with atomic.ActionTimer(self, "dummy_fail_inner_test"):
+                self._play_roulette(exception_probability)
+
+        with atomic.ActionTimer(self, "dummy_fail_test"):
+            self._play_roulette(exception_probability)
+            with atomic.ActionTimer(self, "dummy_fail_inner_test"):
+                self._play_roulette(exception_probability)
 
 
 @scenario.configure(name="Dummy.dummy_random_action")
 class DummyRandomAction(scenario.Scenario):
 
-    def run(self, actions_num=5, sleep_min=0, sleep_max=2):
+    def run(self, actions_num=5, sleep_min=0, sleep_max=0):
         """Sleep random time in dummy actions.
 
         :param actions_num: int number of actions to generate
