@@ -12,22 +12,18 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from rally.common.i18n import _
-from rally.common import logging
 from rally.common import utils as rutils
+from rally.common import validation
 from rally import consts
 from rally.plugins.openstack.cleanup import manager as resource_manager
 from rally.plugins.openstack.scenarios.magnum import utils as magnum_utils
-from rally.plugins.openstack.scenarios.nova import utils as nova_utils
 from rally.task import context
 
 
-LOG = logging.getLogger(__name__)
-
-
-@context.configure(name="cluster_templates", order=470)
+@validation.add("required_platform", platform="openstack", users=True)
+@context.configure(name="cluster_templates", platform="openstack", order=470)
 class ClusterTemplateGenerator(context.Context):
-    """Context class for generating temporary cluster model for benchmarks."""
+    """Creates Magnum cluster template."""
 
     CONFIG_SCHEMA = {
         "type": "object",
@@ -101,34 +97,27 @@ class ClusterTemplateGenerator(context.Context):
         "additionalProperties": False
     }
 
-    @logging.log_task_wrapper(LOG.info, _("Enter context: `ClusterTemplate`"))
     def setup(self):
         for user, tenant_id in rutils.iterate_per_tenants(
                 self.context["users"]):
 
-            nova_scenario = nova_utils.NovaScenario({
-                "user": user,
-                "task": self.context["task"],
-                "config": {"api_versions": self.context["config"].get(
-                    "api_versions", [])}
-            })
-            keypair = nova_scenario._create_keypair()
-
             magnum_scenario = magnum_utils.MagnumScenario({
                 "user": user,
                 "task": self.context["task"],
+                "owner_id": self.context["owner_id"],
                 "config": {"api_versions": self.context["config"].get(
                     "api_versions", [])}
             })
 
             cluster_template = magnum_scenario._create_cluster_template(
-                keypair_id=keypair, **self.config)
+                **self.config)
 
             ct_uuid = cluster_template.uuid
             self.context["tenants"][tenant_id]["cluster_template"] = ct_uuid
 
-    @logging.log_task_wrapper(LOG.info, _("Exit context: `ClusterTemplate`"))
     def cleanup(self):
         resource_manager.cleanup(
-            names=["magnum.cluster_templates", "nova.keypairs"],
-            users=self.context.get("users", []))
+            names=["magnum.cluster_templates"],
+            users=self.context.get("users", []),
+            superclass=magnum_utils.MagnumScenario,
+            task_id=self.get_owner_id())
