@@ -13,8 +13,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from oslo_config import cfg
-
+from rally.common import cfg
 from rally.common import utils
 from rally.common import validation
 from rally import consts as rally_consts
