@@ -17,22 +17,17 @@ import os
 import zipfile
 
 from rally.common import fileutils
-from rally.common.i18n import _
-from rally.common.i18n import _LE
-from rally.common import logging
 from rally.common import utils
+from rally.common import validation
 from rally import consts
 from rally import exceptions
-from rally import osclients
 from rally.plugins.openstack.cleanup import manager as resource_manager
-from rally.plugins.openstack.scenarios.murano import utils as murano_utils
+from rally.plugins.openstack import osclients
 from rally.task import context
 
 
-LOG = logging.getLogger(__name__)
-
-
-@context.configure(name="murano_packages", order=401)
+@validation.add("required_platform", platform="openstack", users=True)
+@context.configure(name="murano_packages", platform="openstack", order=401)
 class PackageGenerator(context.Context):
     """Context class for uploading applications for murano."""
 
@@ -48,7 +43,6 @@ class PackageGenerator(context.Context):
         "additionalProperties": False
     }
 
-    @logging.log_task_wrapper(LOG.info, _("Enter context: `Murano packages`"))
     def setup(self):
         is_config_app_dir = False
         pckg_path = os.path.expanduser(self.config["app_package"])
@@ -58,9 +52,8 @@ class PackageGenerator(context.Context):
             is_config_app_dir = True
             zip_name = fileutils.pack_dir(pckg_path)
         else:
-            msg = (_LE("There is no zip archive or directory by this path:"
-                       " %s") % pckg_path)
-            raise exceptions.ContextSetupFailure(msg=msg,
+            msg = "There is no zip archive or directory by this path: %s"
+            raise exceptions.ContextSetupFailure(msg=msg % pckg_path,
                                                  ctx_name=self.get_name())
 
         for user, tenant_id in utils.iterate_per_tenants(
@@ -69,15 +62,15 @@ class PackageGenerator(context.Context):
             self.context["tenants"][tenant_id]["packages"] = []
             if is_config_app_dir:
                 self.context["tenants"][tenant_id]["murano_ctx"] = zip_name
+            # TODO(astudenov): use self.generate_random_name()
             package = clients.murano().packages.create(
                 {"categories": ["Web"], "tags": ["tag"]},
                 {"file": open(zip_name)})
 
             self.context["tenants"][tenant_id]["packages"].append(package)
 
-    @logging.log_task_wrapper(LOG.info, _("Exit context: `Murano packages`"))
     def cleanup(self):
         resource_manager.cleanup(names=["murano.packages"],
                                  users=self.context.get("users", []),
-                                 superclass=murano_utils.MuranoScenario,
-                                 task_id=self.context["task"]["uuid"])
+                                 superclass=self.__class__,
+                                 task_id=self.get_owner_id())
