@@ -13,8 +13,7 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from oslo_config import cfg
-
+from rally.common import cfg
 from rally.common import utils as rutils
 from rally.common import validation
 from rally import consts
@@ -77,10 +76,12 @@ class SaharaCluster(context.Context):
                 }
             },
             "node_configs": {
-                "type": "object"
+                "type": "object",
+                "additionalProperties": True
             },
             "cluster_configs": {
-                "type": "object"
+                "type": "object",
+                "additionalProperties": True
             },
             "enable_anti_affinity": {
                 "type": "boolean"
