@@ -12,22 +12,19 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-from rally.common.i18n import _
-from rally.common import logging
 from rally.common import utils as rutils
+from rally.common import validation
 from rally import consts
 from rally import exceptions
-from rally import osclients
 from rally.plugins.openstack.cleanup import manager as resource_manager
-from rally.plugins.openstack.scenarios.glance import utils as glance_utils
+from rally.plugins.openstack import osclients
 from rally.plugins.openstack.scenarios.sahara import utils
+from rally.plugins.openstack.services.image import image as image_services
 from rally.task import context
 
 
-LOG = logging.getLogger(__name__)
-
-
-@context.configure(name="sahara_image", order=440)
+@validation.add("required_platform", platform="openstack", users=True)
+@context.configure(name="sahara_image", platform="openstack", order=440)
 class SaharaImage(context.Context):
     """Context class for adding and tagging Sahara images."""
 
@@ -63,20 +60,20 @@ class SaharaImage(context.Context):
 
     def _create_image(self, hadoop_version, image_url, plugin_name, user,
                       user_name):
-        scenario = glance_utils.GlanceScenario(
-            {"user": user, "task": self.context["task"]})
-        image_name = self.generate_random_name()
-        image = scenario._create_image(name=image_name,
-                                       container_format="bare",
-                                       image_location=image_url,
-                                       disk_format="qcow2")
-        scenario.clients("sahara").images.update_image(
+        clients = osclients.Clients(
+            user["credential"],
+            api_info=self.context["config"].get("api_versions"))
+        image_service = image_services.Image(
+            clients, name_generator=self.generate_random_name)
+        image = image_service.create_image(container_format="bare",
+                                           image_location=image_url,
+                                           disk_format="qcow2")
+        clients.sahara().images.update_image(
             image_id=image.id, user_name=user_name, desc="")
-        scenario.clients("sahara").images.update_tags(
+        clients.sahara().images.update_tags(
             image_id=image.id, new_tags=[plugin_name, hadoop_version])
         return image.id
 
-    @logging.log_task_wrapper(LOG.info, _("Enter context: `Sahara Image`"))
     def setup(self):
         utils.init_sahara_context(self)
         self.context["sahara"]["images"] = {}
@@ -101,8 +98,10 @@ class SaharaImage(context.Context):
                 visibility = image["visibility"]
 
             if visibility != "public":
-                raise exceptions.BenchmarkSetupFailure(
-                    "Image provided in the Sahara context should be public.")
+                raise exceptions.ContextSetupFailure(
+                    ctx_name=self.get_name(),
+                    msg="Use only public image for sahara_image context"
+                )
             image_id = image_uuid
 
             for user, tenant_id in rutils.iterate_per_tenants(
@@ -123,10 +122,9 @@ class SaharaImage(context.Context):
                 self.context["tenants"][tenant_id]["sahara"]["image"] = (
                     image_id)
 
-    @logging.log_task_wrapper(LOG.info, _("Exit context: `Sahara Image`"))
     def cleanup(self):
         if self.context["sahara"]["need_image_cleanup"]:
             resource_manager.cleanup(names=["glance.images"],
                                      users=self.context.get("users", []),
-                                     superclass=glance_utils.GlanceScenario,
-                                     task_id=self.context["task"]["uuid"])
+                                     superclass=self.__class__,
+                                     task_id=self.get_owner_id())
