@@ -21,8 +21,8 @@ from rally.task import validation
 """Scenarios for Authentication mechanism."""
 
 
-@validation.required_openstack(users=True)
-@scenario.configure(name="Authenticate.keystone")
+@validation.add("required_platform", platform="openstack", users=True)
+@scenario.configure(name="Authenticate.keystone", platform="openstack")
 class Keystone(scenario.OpenStackScenario):
 
     @atomic.action_timer("authenticate.keystone")
@@ -31,9 +31,9 @@ class Keystone(scenario.OpenStackScenario):
         self.clients("keystone")
 
 
-@validation.number("repetitions", minval=1)
-@validation.required_openstack(users=True)
-@scenario.configure(name="Authenticate.validate_glance")
+@validation.add("number", param_name="repetitions", minval=1)
+@validation.add("required_platform", platform="openstack", users=True)
+@scenario.configure(name="Authenticate.validate_glance", platform="openstack")
 class ValidateGlance(scenario.OpenStackScenario):
 
     def run(self, repetitions):
@@ -47,16 +47,14 @@ class ValidateGlance(scenario.OpenStackScenario):
         """
         glance_client = self.clients("glance")
         image_name = "__intentionally_non_existent_image___"
-        with atomic.ActionTimer(
-                self,
-                "authenticate.validate_glance_%s_times" % repetitions):
+        with atomic.ActionTimer(self, "authenticate.validate_glance"):
             for i in range(repetitions):
                 list(glance_client.images.list(name=image_name))
 
 
-@validation.number("repetitions", minval=1)
-@validation.required_openstack(users=True)
-@scenario.configure(name="Authenticate.validate_nova")
+@validation.add("number", param_name="repetitions", minval=1)
+@validation.add("required_platform", platform="openstack", users=True)
+@scenario.configure(name="Authenticate.validate_nova", platform="openstack")
 class ValidateNova(scenario.OpenStackScenario):
 
     def run(self, repetitions):
@@ -68,16 +66,15 @@ class ValidateNova(scenario.OpenStackScenario):
         :param repetitions: number of times to validate
         """
         nova_client = self.clients("nova")
-        with atomic.ActionTimer(
-                self,
-                "authenticate.validate_nova_%s_times" % repetitions):
+        with atomic.ActionTimer(self, "authenticate.validate_nova"):
             for i in range(repetitions):
                 nova_client.flavors.list()
 
 
-@validation.number("repetitions", minval=1)
-@validation.required_openstack(users=True)
-@scenario.configure(name="Authenticate.validate_ceilometer")
+@validation.add("number", param_name="repetitions", minval=1)
+@validation.add("required_platform", platform="openstack", users=True)
+@scenario.configure(name="Authenticate.validate_ceilometer",
+                    platform="openstack")
 class ValidateCeilometer(scenario.OpenStackScenario):
 
     def run(self, repetitions):
@@ -89,16 +86,14 @@ class ValidateCeilometer(scenario.OpenStackScenario):
         :param repetitions: number of times to validate
         """
         ceilometer_client = self.clients("ceilometer")
-        with atomic.ActionTimer(
-                self,
-                "authenticate.validate_ceilometer_%s_times" % repetitions):
+        with atomic.ActionTimer(self, "authenticate.validate_ceilometer"):
             for i in range(repetitions):
                 ceilometer_client.meters.list()
 
 
-@validation.number("repetitions", minval=1)
-@validation.required_openstack(users=True)
-@scenario.configure(name="Authenticate.validate_cinder")
+@validation.add("number", param_name="repetitions", minval=1)
+@validation.add("required_platform", platform="openstack", users=True)
+@scenario.configure(name="Authenticate.validate_cinder", platform="openstack")
 class ValidateCinder(scenario.OpenStackScenario):
 
     def run(self, repetitions):
@@ -110,16 +105,14 @@ class ValidateCinder(scenario.OpenStackScenario):
         :param repetitions: number of times to validate
         """
         cinder_client = self.clients("cinder")
-        with atomic.ActionTimer(
-                self,
-                "authenticate.validate_cinder_%s_times" % repetitions):
+        with atomic.ActionTimer(self, "authenticate.validate_cinder"):
             for i in range(repetitions):
                 cinder_client.volume_types.list()
 
 
-@validation.number("repetitions", minval=1)
-@validation.required_openstack(users=True)
-@scenario.configure(name="Authenticate.validate_neutron")
+@validation.add("number", param_name="repetitions", minval=1)
+@validation.add("required_platform", platform="openstack", users=True)
+@scenario.configure(name="Authenticate.validate_neutron", platform="openstack")
 class ValidateNeutron(scenario.OpenStackScenario):
 
     def run(self, repetitions):
@@ -131,16 +124,14 @@ class ValidateNeutron(scenario.OpenStackScenario):
         :param repetitions: number of times to validate
         """
         neutron_client = self.clients("neutron")
-        with atomic.ActionTimer(
-                self,
-                "authenticate.validate_neutron_%s_times" % repetitions):
+        with atomic.ActionTimer(self, "authenticate.validate_neutron"):
             for i in range(repetitions):
                 neutron_client.list_networks()
 
 
-@validation.number("repetitions", minval=1)
-@validation.required_openstack(users=True)
-@scenario.configure(name="Authenticate.validate_heat")
+@validation.add("number", param_name="repetitions", minval=1)
+@validation.add("required_platform", platform="openstack", users=True)
+@scenario.configure(name="Authenticate.validate_heat", platform="openstack")
 class ValidateHeat(scenario.OpenStackScenario):
 
     def run(self, repetitions):
@@ -152,17 +143,16 @@ class ValidateHeat(scenario.OpenStackScenario):
         :param repetitions: number of times to validate
         """
         heat_client = self.clients("heat")
-        with atomic.ActionTimer(
-                self,
-                "authenticate.validate_heat_%s_times" % repetitions):
+        with atomic.ActionTimer(self, "authenticate.validate_heat"):
             for i in range(repetitions):
                 list(heat_client.stacks.list(limit=0))
 
 
-@validation.number("repetitions", minval=1)
-@validation.required_openstack(users=True)
-@validation.required_services(consts.Service.MONASCA)
-@scenario.configure(name="Authenticate.validate_monasca")
+@validation.add("number", param_name="repetitions", minval=1)
+@validation.add("required_platform", platform="openstack", users=True)
+@validation.add("required_services",
+                services=[consts.Service.MONASCA])
+@scenario.configure(name="Authenticate.validate_monasca", platform="openstack")
 class ValidateMonasca(scenario.OpenStackScenario):
 
     def run(self, repetitions):
@@ -174,8 +164,6 @@ class ValidateMonasca(scenario.OpenStackScenario):
         :param repetitions: number of times to validate
         """
         monasca_client = self.clients("monasca")
-        with atomic.ActionTimer(
-                self,
-                "authenticate.validate_monasca_%s_times" % repetitions):
+        with atomic.ActionTimer(self, "authenticate.validate_monasca"):
             for i in range(repetitions):
                 list(monasca_client.metrics.list(limit=0))
