@@ -17,13 +17,13 @@ from rally.plugins.openstack import scenario
 from rally.plugins.openstack.scenarios.ceilometer import utils as ceiloutils
 from rally.task import validation
 
-"""Benchmark scenarios for Ceilometer Alarms API."""
 
-
-@validation.required_services(consts.Service.CEILOMETER)
-@validation.required_openstack(users=True)
-@scenario.configure(context={"cleanup": ["ceilometer"]},
-                    name="CeilometerAlarms.create_alarm")
+@validation.add("required_services",
+                services=[consts.Service.CEILOMETER])
+@validation.add("required_platform", platform="openstack", users=True)
+@scenario.configure(context={"cleanup@openstack": ["ceilometer"]},
+                    name="CeilometerAlarms.create_alarm",
+                    platform="openstack")
 class CreateAlarm(ceiloutils.CeilometerScenario):
 
     def run(self, meter_name, threshold, **kwargs):
@@ -42,9 +42,10 @@ class CreateAlarm(ceiloutils.CeilometerScenario):
         self._create_alarm(meter_name, threshold, kwargs)
 
 
-@validation.required_services(consts.Service.CEILOMETER)
-@validation.required_openstack(users=True)
-@scenario.configure(name="CeilometerAlarms.list_alarms")
+@validation.add("required_services",
+                services=[consts.Service.CEILOMETER])
+@validation.add("required_platform", platform="openstack", users=True)
+@scenario.configure(name="CeilometerAlarms.list_alarms", platform="openstack")
 class ListAlarms(ceiloutils.CeilometerScenario):
 
     def run(self):
@@ -55,10 +56,12 @@ class ListAlarms(ceiloutils.CeilometerScenario):
         self._list_alarms()
 
 
-@validation.required_services(consts.Service.CEILOMETER)
-@validation.required_openstack(users=True)
-@scenario.configure(context={"cleanup": ["ceilometer"]},
-                    name="CeilometerAlarms.create_and_list_alarm")
+@validation.add("required_services",
+                services=[consts.Service.CEILOMETER])
+@validation.add("required_platform", platform="openstack", users=True)
+@scenario.configure(context={"cleanup@openstack": ["ceilometer"]},
+                    name="CeilometerAlarms.create_and_list_alarm",
+                    platform="openstack")
 class CreateAndListAlarm(ceiloutils.CeilometerScenario):
 
     def run(self, meter_name, threshold, **kwargs):
@@ -79,10 +82,12 @@ class CreateAndListAlarm(ceiloutils.CeilometerScenario):
         self._list_alarms(alarm.alarm_id)
 
 
-@validation.required_services(consts.Service.CEILOMETER)
-@validation.required_openstack(users=True)
-@scenario.configure(context={"cleanup": ["ceilometer"]},
-                    name="CeilometerAlarms.create_and_get_alarm")
+@validation.add("required_services",
+                services=[consts.Service.CEILOMETER])
+@validation.add("required_platform", platform="openstack", users=True)
+@scenario.configure(context={"cleanup@openstack": ["ceilometer"]},
+                    name="CeilometerAlarms.create_and_get_alarm",
+                    platform="openstack")
 class CreateAndGetAlarm(ceiloutils.CeilometerScenario):
 
     def run(self, meter_name, threshold, **kwargs):
@@ -103,10 +108,12 @@ class CreateAndGetAlarm(ceiloutils.CeilometerScenario):
         self._get_alarm(alarm.alarm_id)
 
 
-@validation.required_services(consts.Service.CEILOMETER)
-@validation.required_openstack(users=True)
-@scenario.configure(context={"cleanup": ["ceilometer"]},
-                    name="CeilometerAlarms.create_and_update_alarm")
+@validation.add("required_services",
+                services=[consts.Service.CEILOMETER])
+@validation.add("required_platform", platform="openstack", users=True)
+@scenario.configure(context={"cleanup@openstack": ["ceilometer"]},
+                    name="CeilometerAlarms.create_and_update_alarm",
+                    platform="openstack")
 class CreateAndUpdateAlarm(ceiloutils.CeilometerScenario):
 
     def run(self, meter_name, threshold, **kwargs):
@@ -127,10 +134,12 @@ class CreateAndUpdateAlarm(ceiloutils.CeilometerScenario):
         self._update_alarm(alarm.alarm_id, alarm_dict_diff)
 
 
-@validation.required_services(consts.Service.CEILOMETER)
-@validation.required_openstack(users=True)
-@scenario.configure(context={"cleanup": ["ceilometer"]},
-                    name="CeilometerAlarms.create_and_delete_alarm")
+@validation.add("required_services",
+                services=[consts.Service.CEILOMETER])
+@validation.add("required_platform", platform="openstack", users=True)
+@scenario.configure(context={"cleanup@openstack": ["ceilometer"]},
+                    name="CeilometerAlarms.create_and_delete_alarm",
+                    platform="openstack")
 class CreateAndDeleteAlarm(ceiloutils.CeilometerScenario):
 
     def run(self, meter_name, threshold, **kwargs):
@@ -150,10 +159,12 @@ class CreateAndDeleteAlarm(ceiloutils.CeilometerScenario):
         self._delete_alarm(alarm.alarm_id)
 
 
-@validation.required_services(consts.Service.CEILOMETER)
-@validation.required_openstack(users=True)
-@scenario.configure(context={"cleanup": ["ceilometer"]},
-                    name="CeilometerAlarms.create_alarm_and_get_history")
+@validation.add("required_services",
+                services=[consts.Service.CEILOMETER])
+@validation.add("required_platform", platform="openstack", users=True)
+@scenario.configure(context={"cleanup@openstack": ["ceilometer"]},
+                    name="CeilometerAlarms.create_alarm_and_get_history",
+                    platform="openstack")
 class CreateAlarmAndGetHistory(ceiloutils.CeilometerScenario):
 
     def run(self, meter_name, threshold, state, timeout=60, **kwargs):
