@@ -13,6 +13,7 @@
 #    under the License.
 
 import datetime as dt
+import uuid
 
 import six
 
@@ -52,7 +53,7 @@ class CeilometerScenario(scenario.OpenStackScenario):
             "counter_type": counter_type,
             "counter_unit": counter_unit,
             "counter_volume": counter_volume,
-            "resource_id": self.generate_random_name()
+            "resource_id": str(uuid.uuid4())
         }
         opt_fields = {
             "project_id": project_id,
@@ -98,7 +99,7 @@ class CeilometerScenario(scenario.OpenStackScenario):
                             filter_by_user_id=None,
                             filter_by_resource_id=None,
                             metadata_query=None):
-        """Create a SimpleQuery for the list benchmarks.
+        """Create a SimpleQuery used by samples list API.
 
         :param filter_by_project_id: add a project id to query
         :param filter_by_user_id: add a user id to query
@@ -258,11 +259,11 @@ class CeilometerScenario(scenario.OpenStackScenario):
         :returns: alarm in the set state
         """
         self.clients("ceilometer").alarms.set_state(alarm.alarm_id, state)
-        return bench_utils.wait_for(alarm,
-                                    ready_statuses=[state],
-                                    update_resource=bench_utils
-                                    .get_from_manager(),
-                                    timeout=timeout, check_interval=1)
+        return bench_utils.wait_for_status(alarm,
+                                           ready_statuses=[state],
+                                           update_resource=bench_utils
+                                           .get_from_manager(),
+                                           timeout=timeout, check_interval=1)
 
     @atomic.action_timer("ceilometer.list_events")
     def _list_events(self):
