@@ -58,16 +58,12 @@ class DesignateScenario(scenario.OpenStackScenario):
         domain["email"] = "updated@random.name"
         return self.clients("designate").domains.update(domain)
 
-    @atomic.optional_action_timer("designate.create_record")
+    @atomic.action_timer("designate.create_record")
     def _create_record(self, domain, record=None):
         """Create a record in a domain.
 
         :param domain: domain dict
         :param record: record dict
-        :param atomic_action: True if the record creation should be
-                              tracked as an atomic action. added and
-                              handled by the optional_action_timer()
-                              decorator
         :returns: Designate record dict
         """
         record = record or {}
@@ -76,9 +72,7 @@ class DesignateScenario(scenario.OpenStackScenario):
                                     domain["name"])
         record.setdefault("data", "10.0.0.1")
 
-        client = self.clients("designate")
-
-        return client.records.create(domain["id"], record)
+        return self.clients("designate").records.create(domain["id"], record)
 
     @atomic.action_timer("designate.list_records")
     def _list_records(self, domain_id):
@@ -89,16 +83,12 @@ class DesignateScenario(scenario.OpenStackScenario):
         """
         return self.clients("designate").records.list(domain_id)
 
-    @atomic.optional_action_timer("designate.delete_record")
+    @atomic.action_timer("designate.delete_record")
     def _delete_record(self, domain_id, record_id):
         """Delete a domain record.
 
         :param domain_id: domain ID
         :param record_id: record ID
-        :param atomic_action: True if the record creation should be
-                              tracked as an atomic action. added and
-                              handled by the optional_action_timer()
-                              decorator
         """
         self.clients("designate").records.delete(domain_id, record_id)
 
@@ -111,7 +101,7 @@ class DesignateScenario(scenario.OpenStackScenario):
         """
         server = server or {}
 
-        server["name"] = "name.%s." % self.generate_random_name()
+        server["name"] = "%s.name." % self.generate_random_name()
         return self.admin_clients("designate").servers.create(server)
 
     @atomic.action_timer("designate.list_servers")
@@ -188,15 +178,12 @@ class DesignateScenario(scenario.OpenStackScenario):
         return self.clients("designate", version="2").recordsets.list(
             zone_id, criterion=criterion, marker=marker, limit=limit)
 
-    @atomic.optional_action_timer("designate.create_recordset")
+    @atomic.action_timer("designate.create_recordset")
     def _create_recordset(self, zone, recordset=None):
         """Create a recordset in a zone.
 
         :param zone: zone dict
         :param recordset: recordset dict
-        :param atomic_action: True if this is an atomic action. added
-                              and handled by the
-                              optional_action_timer() decorator
         :returns: Designate recordset dict
         """
         recordset = recordset or {}
@@ -210,15 +197,12 @@ class DesignateScenario(scenario.OpenStackScenario):
         return self.clients("designate", version="2").recordsets.create(
             zone["id"], **recordset)
 
-    @atomic.optional_action_timer("designate.delete_recordset")
+    @atomic.action_timer("designate.delete_recordset")
     def _delete_recordset(self, zone_id, recordset_id):
         """Delete a zone recordset.
 
         :param zone_id: Zone ID
         :param recordset_id: Recordset ID
-        :param atomic_action: True if this is an atomic action. added
-                              and handled by the
-                              optional_action_timer() decorator
         """
 
         self.clients("designate", version="2").recordsets.delete(
