@@ -25,19 +25,22 @@ from rally.task import validation
 
 @logging.log_deprecated_args("Useless arguments detected", "0.10.0",
                              ("marker", "limit", "sort_key"), once=True)
-@validation.restricted_parameters(["name"])
-@validation.required_services(consts.Service.IRONIC)
-@validation.required_openstack(admin=True)
-@scenario.configure(context={"admin_cleanup": ["ironic"]},
-                    name="IronicNodes.create_and_list_node")
+@validation.add("required_services", services=[consts.Service.IRONIC])
+@validation.add("restricted_parameters", param_names="name")
+@validation.add("required_platform", platform="openstack", admin=True)
+@scenario.configure(context={"admin_cleanup@openstack": ["ironic"]},
+                    name="IronicNodes.create_and_list_node",
+                    platform="openstack")
 class CreateAndListNode(utils.IronicScenario):
 
-    def run(self, driver, associated=None, maintenance=None, detail=False,
-            sort_dir=None, marker=None, limit=None, sort_key=None,
-            **kwargs):
+    def run(self, driver, properties=None, associated=None, maintenance=None,
+            detail=False, sort_dir=None, marker=None, limit=None,
+            sort_key=None, **kwargs):
         """Create and list nodes.
 
         :param driver: The name of the driver used to manage this Node.
+        :param properties: Key/value pair describing the physical
+            characteristics of the node.
         :param associated: Optional argument of list request. Either a Boolean
             or a string representation of a Boolean that indicates whether to
             return a list of associated (True or "True") or unassociated
@@ -56,25 +59,28 @@ class CreateAndListNode(utils.IronicScenario):
         :param kwargs: Optional additional arguments for node creation
         """
 
-        node = self._create_node(driver, **kwargs)
+        node = self._create_node(driver, properties, **kwargs)
         list_nodes = self._list_nodes(
             associated=associated, maintenance=maintenance, detail=detail,
             sort_dir=sort_dir)
         self.assertIn(node.name, [n.name for n in list_nodes])
 
 
-@validation.restricted_parameters(["name"])
-@validation.required_services(consts.Service.IRONIC)
-@validation.required_openstack(admin=True)
-@scenario.configure(context={"admin_cleanup": ["ironic"]},
-                    name="IronicNodes.create_and_delete_node")
+@validation.add("required_services", services=[consts.Service.IRONIC])
+@validation.add("restricted_parameters", param_names="name")
+@validation.add("required_platform", platform="openstack", admin=True)
+@scenario.configure(context={"admin_cleanup@openstack": ["ironic"]},
+                    name="IronicNodes.create_and_delete_node",
+                    platform="openstack")
 class CreateAndDeleteNode(utils.IronicScenario):
 
-    def run(self, driver, **kwargs):
+    def run(self, driver, properties=None, **kwargs):
         """Create and delete node.
 
         :param driver: The name of the driver used to manage this Node.
+        :param properties: Key/value pair describing the physical
+            characteristics of the node.
         :param kwargs: Optional additional arguments for node creation
         """
-        node = self._create_node(driver, **kwargs)
+        node = self._create_node(driver, properties, **kwargs)
         self._delete_node(node)
