@@ -15,8 +15,7 @@
 
 import string
 
-from oslo_config import cfg
-
+from rally.common import cfg
 from rally.plugins.openstack import scenario
 from rally.task import atomic
 from rally.task import utils
