@@ -15,7 +15,6 @@
 
 import uuid
 
-from rally.common.i18n import _LW
 from rally.common import logging
 from rally.plugins.openstack import scenario
 from rally.plugins.openstack.wrappers import keystone as keystone_wrapper
@@ -30,11 +29,11 @@ class KeystoneScenario(scenario.OpenStackScenario):
 
     def __init__(self, context=None, admin_clients=None, clients=None):
         super(KeystoneScenario, self).__init__(context, admin_clients, clients)
-        LOG.warning(_LW(
+        LOG.warning(
             "Class %s is deprecated since Rally 0.8.0 and will be removed "
             "soon. Use "
             "rally.plugins.openstack.services.identity.identity.Identity "
-            "instead.") % self.__class__)
+            "instead." % self.__class__)
 
     @atomic.action_timer("keystone.create_user")
     def _user_create(self, email=None, **kwargs):
@@ -71,7 +70,7 @@ class KeystoneScenario(scenario.OpenStackScenario):
         """
         self.admin_clients("keystone").tokens.validate(token)
 
-    @atomic.optional_action_timer("keystone.token_authenticate")
+    @atomic.action_timer("keystone.token_authenticate")
     def _authenticate_token(self, name, password, tenant_id, tenant):
         """Authenticate user token.
 
@@ -79,10 +78,6 @@ class KeystoneScenario(scenario.OpenStackScenario):
         :param password: User password for authentication
         :param tenant_id: Tenant id for authentication
         :param tenant: Tenant on which authentication will take place
-        :param atomic_action: bool, enable user authentication to be
-                              tracked as an atomic action. added and
-                              handled by the optional_action_timer()
-                              decorator
         """
         return self.admin_clients("keystone").tokens.authenticate(name,
                                                                   tenant_id,
