@@ -15,15 +15,17 @@
 from rally import consts
 from rally.plugins.openstack import scenario
 from rally.plugins.openstack.scenarios.magnum import utils
+from rally.plugins.openstack.scenarios.nova import utils as nova_utils
 from rally.task import validation
 
 """Scenarios for Magnum clusters."""
 
 
-@validation.required_services(consts.Service.MAGNUM)
-@validation.required_openstack(users=True)
-@scenario.configure(context={"cleanup": ["magnum.clusters"]},
-                    name="MagnumClusters.list_clusters")
+@validation.add("required_services", services=[consts.Service.MAGNUM])
+@validation.add("required_platform", platform="openstack", users=True)
+@scenario.configure(context={"cleanup@openstack": ["magnum.clusters"]},
+                    name="MagnumClusters.list_clusters",
+                    platform="openstack")
 class ListClusters(utils.MagnumScenario):
 
     def run(self, **kwargs):
@@ -43,11 +45,12 @@ class ListClusters(utils.MagnumScenario):
         self._list_clusters(**kwargs)
 
 
-@validation.required_services(consts.Service.MAGNUM)
-@validation.required_openstack(users=True)
-@validation.required_contexts("cluster_templates")
-@scenario.configure(context={"cleanup": ["magnum.clusters"]},
-                    name="MagnumClusters.create_and_list_clusters")
+@validation.add("required_services", services=[consts.Service.MAGNUM])
+@validation.add("required_platform", platform="openstack", users=True)
+@scenario.configure(
+    context={"cleanup@openstack": ["magnum.clusters", "nova.keypairs"]},
+    name="MagnumClusters.create_and_list_clusters",
+    platform="openstack")
 class CreateAndListClusters(utils.MagnumScenario):
 
     def run(self, node_count, **kwargs):
@@ -61,8 +64,20 @@ class CreateAndListClusters(utils.MagnumScenario):
         cluster_template_uuid = kwargs.get("cluster_template_uuid", None)
         if cluster_template_uuid is None:
             cluster_template_uuid = self.context["tenant"]["cluster_template"]
-        cluster = self._create_cluster(cluster_template_uuid,
-                                       node_count, **kwargs)
-        self.assertTrue(cluster)
-        list_clusters = self._list_clusters(**kwargs)
-        self.assertIn(cluster, list_clusters)
+        else:
+            del kwargs["cluster_template_uuid"]
+
+        nova_scenario = nova_utils.NovaScenario({
+            "user": self.context["user"],
+            "task": self.context["task"],
+            "config": {"api_versions": self.context["config"].get(
+                "api_versions", [])}
+        })
+        keypair = nova_scenario._create_keypair()
+
+        new_cluster = self._create_cluster(cluster_template_uuid, node_count,
+                                           keypair=keypair, **kwargs)
+        self.assertTrue(new_cluster, "Failed to create new cluster")
+        clusters = self._list_clusters(**kwargs)
+        self.assertIn(new_cluster.uuid, [cluster.uuid for cluster in clusters],
+                      "New cluster not found in a list of clusters")
