@@ -23,10 +23,11 @@ from rally.task import validation
 """Scenarios for Mistral workbook."""
 
 
-@validation.required_clients("mistral")
-@validation.required_openstack(users=True)
-@validation.required_services(consts.Service.MISTRAL)
-@scenario.configure(name="MistralWorkbooks.list_workbooks")
+@validation.add("required_platform", platform="openstack", users=True)
+@validation.add("required_services",
+                services=[consts.Service.MISTRAL])
+@scenario.configure(name="MistralWorkbooks.list_workbooks",
+                    platform="openstack")
 class ListWorkbooks(utils.MistralScenario):
 
     def run(self):
@@ -38,14 +39,14 @@ class ListWorkbooks(utils.MistralScenario):
         self._list_workbooks()
 
 
-@validation.required_parameters("definition")
-@validation.file_exists("definition")
 @types.convert(definition={"type": "file"})
-@validation.required_clients("mistral")
-@validation.required_openstack(users=True)
-@validation.required_services(consts.Service.MISTRAL)
-@scenario.configure(context={"cleanup": ["mistral"]},
-                    name="MistralWorkbooks.create_workbook")
+@validation.add("file_exists", param_name="definition")
+@validation.add("required_platform", platform="openstack", users=True)
+@validation.add("required_services",
+                services=[consts.Service.MISTRAL])
+@scenario.configure(context={"cleanup@openstack": ["mistral"]},
+                    name="MistralWorkbooks.create_workbook",
+                    platform="openstack")
 class CreateWorkbook(utils.MistralScenario):
 
     def run(self, definition, do_delete=False):
