@@ -16,17 +16,15 @@
 from rally import consts
 from rally.plugins.openstack import scenario
 from rally.plugins.openstack.scenarios.murano import utils
-from rally.task import atomic
 from rally.task import validation
 
 
 """Scenarios for Murano environments."""
 
 
-@validation.required_clients("murano")
-@validation.required_services(consts.Service.MURANO)
-@scenario.configure(context={"cleanup": ["murano.environments"]},
-                    name="MuranoEnvironments.list_environments")
+@validation.add("required_services", services=[consts.Service.MURANO])
+@scenario.configure(name="MuranoEnvironments.list_environments",
+                    platform="openstack")
 class ListEnvironments(utils.MuranoScenario):
 
     def run(self):
@@ -37,10 +35,10 @@ class ListEnvironments(utils.MuranoScenario):
         self._list_environments()
 
 
-@validation.required_clients("murano")
-@validation.required_services(consts.Service.MURANO)
-@scenario.configure(context={"cleanup": ["murano.environments"]},
-                    name="MuranoEnvironments.create_and_delete_environment")
+@validation.add("required_services", services=[consts.Service.MURANO])
+@scenario.configure(context={"cleanup@openstack": ["murano.environments"]},
+                    name="MuranoEnvironments.create_and_delete_environment",
+                    platform="openstack")
 class CreateAndDeleteEnvironment(utils.MuranoScenario):
 
     def run(self):
@@ -51,11 +49,12 @@ class CreateAndDeleteEnvironment(utils.MuranoScenario):
         self._delete_environment(environment)
 
 
-@validation.required_clients("murano")
-@validation.required_services(consts.Service.MURANO)
-@validation.required_contexts("murano_packages")
-@scenario.configure(context={"cleanup": ["murano"], "roles": ["admin"]},
-                    name="MuranoEnvironments.create_and_deploy_environment")
+@validation.add("required_services", services=[consts.Service.MURANO])
+@validation.add("required_contexts", contexts=("murano_packages"))
+@scenario.configure(context={"cleanup@openstack": ["murano"],
+                             "roles@openstack": ["admin"]},
+                    name="MuranoEnvironments.create_and_deploy_environment",
+                    platform="openstack")
 class CreateAndDeployEnvironment(utils.MuranoScenario):
 
     def run(self, packages_per_env=1):
@@ -70,10 +69,8 @@ class CreateAndDeployEnvironment(utils.MuranoScenario):
         session = self._create_session(environment.id)
         package = self.context["tenant"]["packages"][0]
 
-        with atomic.ActionTimer(self, "murano.create_services"):
-            for i in range(packages_per_env):
-                self._create_service(environment, session,
-                                     package.fully_qualified_name,
-                                     atomic_action=False)
+        for i in range(packages_per_env):
+            self._create_service(environment, session,
+                                 package.fully_qualified_name)
 
         self._deploy_environment(environment, session)
