@@ -19,12 +19,14 @@ from rally.task import validation
 """Scenarios for Neutron Loadbalancer v2."""
 
 
-@validation.required_neutron_extensions("lbaasv2")
-@validation.required_services(consts.Service.NEUTRON)
-@validation.required_openstack(users=True)
-@validation.required_contexts("network")
-@scenario.configure(context={"cleanup": ["neutron"]},
-                    name="NeutronLoadbalancerV2.create_and_list_loadbalancers")
+@validation.add("required_neutron_extensions", extensions=["lbaasv2"])
+@validation.add("required_services",
+                services=[consts.Service.NEUTRON])
+@validation.add("required_platform", platform="openstack", users=True)
+@validation.add("required_contexts", contexts=("network"))
+@scenario.configure(context={"cleanup@openstack": ["neutron"]},
+                    name="NeutronLoadbalancerV2.create_and_list_loadbalancers",
+                    platform="openstack")
 class CreateAndListLoadbalancers(utils.NeutronScenario):
 
     def run(self, lb_create_args=None):
