@@ -22,11 +22,10 @@ from rally.task import validation
 """Scenarios for Nova agents."""
 
 
-@validation.required_services(consts.Service.NOVA)
-@validation.required_openstack(admin=True)
-@scenario.configure(name="NovaAgents.list_agents")
+@validation.add("required_services", services=[consts.Service.NOVA])
+@validation.add("required_platform", platform="openstack", admin=True)
+@scenario.configure(name="NovaAgents.list_agents", platform="openstack")
 class ListAgents(utils.NovaScenario):
-
     def run(self, hypervisor=None):
         """List all builds.
 
