@@ -22,9 +22,10 @@ from rally.task import validation
 """Scenarios for Nova availability-zones."""
 
 
-@validation.required_services(consts.Service.NOVA)
-@validation.required_openstack(admin=True)
-@scenario.configure(name="NovaAvailabilityZones.list_availability_zones")
+@validation.add("required_services", services=[consts.Service.NOVA])
+@validation.add("required_platform", platform="openstack", admin=True)
+@scenario.configure(name="NovaAvailabilityZones.list_availability_zones",
+                    platform="openstack")
 class ListAvailabilityZones(utils.NovaScenario):
 
     def run(self, detailed=True):
