@@ -16,16 +16,16 @@
 from rally import consts
 from rally.plugins.openstack import scenario
 from rally.plugins.openstack.scenarios.nova import utils
-from rally.task import atomic
 from rally.task import validation
 
 
 """Scenarios for Nova hypervisors."""
 
 
-@validation.required_services(consts.Service.NOVA)
-@validation.required_openstack(admin=True)
-@scenario.configure(name="NovaHypervisors.list_hypervisors")
+@validation.add("required_services", services=[consts.Service.NOVA])
+@validation.add("required_platform", platform="openstack", admin=True)
+@scenario.configure(name="NovaHypervisors.list_hypervisors",
+                    platform="openstack")
 class ListHypervisors(utils.NovaScenario):
 
     def run(self, detailed=True):
@@ -39,11 +39,12 @@ class ListHypervisors(utils.NovaScenario):
         self._list_hypervisors(detailed)
 
 
-@validation.required_services(consts.Service.NOVA)
-@validation.required_openstack(admin=True)
-@scenario.configure(name="NovaHypervisors.list_and_get_hypervisors")
+@validation.add("required_services", services=[consts.Service.NOVA])
+@validation.add("required_platform", platform="openstack", admin=True)
+@scenario.configure(name="NovaHypervisors.list_and_get_hypervisors",
+                    platform="openstack")
 class ListAndGetHypervisors(utils.NovaScenario):
-    """Benchmark scenario for Nova hypervisors."""
+
     def run(self, detailed=True):
         """List and Get hypervisors.
 
@@ -57,14 +58,14 @@ class ListAndGetHypervisors(utils.NovaScenario):
         """
         hypervisors = self._list_hypervisors(detailed)
 
-        with atomic.ActionTimer(self, "nova.get_hypervisor"):
-            for hypervisor in hypervisors:
-                self._get_hypervisor(hypervisor, atomic_action=False)
+        for hypervisor in hypervisors:
+            self._get_hypervisor(hypervisor)
 
 
-@validation.required_services(consts.Service.NOVA)
-@validation.required_openstack(admin=True)
-@scenario.configure(name="NovaHypervisors.statistics_hypervisors")
+@validation.add("required_services", services=[consts.Service.NOVA])
+@validation.add("required_platform", platform="openstack", admin=True)
+@scenario.configure(name="NovaHypervisors.statistics_hypervisors",
+                    platform="openstack")
 class StatisticsHypervisors(utils.NovaScenario):
 
     def run(self):
@@ -75,10 +76,12 @@ class StatisticsHypervisors(utils.NovaScenario):
         self._statistics_hypervisors()
 
 
-@validation.required_services(consts.Service.NOVA)
-@validation.required_openstack(admin=True)
-@scenario.configure(name="NovaHypervisors.list_and_get_uptime_hypervisors")
+@validation.add("required_services", services=[consts.Service.NOVA])
+@validation.add("required_platform", platform="openstack", admin=True)
+@scenario.configure(name="NovaHypervisors.list_and_get_uptime_hypervisors",
+                    platform="openstack")
 class ListAndGetUptimeHypervisors(utils.NovaScenario):
+
     def run(self, detailed=True):
         """List hypervisors,then display the uptime of it.
 
@@ -92,15 +95,16 @@ class ListAndGetUptimeHypervisors(utils.NovaScenario):
         """
         hypervisors = self._list_hypervisors(detailed)
 
-        with atomic.ActionTimer(self, "nova.uptime_hypervisor"):
-            for hypervisor in hypervisors:
-                self._uptime_hypervisor(hypervisor, atomic_action=False)
+        for hypervisor in hypervisors:
+            self._uptime_hypervisor(hypervisor)
 
 
-@validation.required_services(consts.Service.NOVA)
-@validation.required_openstack(admin=True)
-@scenario.configure(name="NovaHypervisors.list_and_search_hypervisors")
+@validation.add("required_services", services=[consts.Service.NOVA])
+@validation.add("required_platform", platform="openstack", admin=True)
+@scenario.configure(name="NovaHypervisors.list_and_search_hypervisors",
+                    platform="openstack")
 class ListAndSearchHypervisors(utils.NovaScenario):
+
     def run(self, detailed=True):
         """List all servers belonging to specific hypervisor.
 
@@ -114,9 +118,5 @@ class ListAndSearchHypervisors(utils.NovaScenario):
         """
         hypervisors = self._list_hypervisors(detailed)
 
-        with atomic.ActionTimer(self,
-                                "nova.search_%s_hypervisors" % len(hypervisors)
-                                ):
-            for hypervisor in hypervisors:
-                self._search_hypervisors(hypervisor.hypervisor_hostname,
-                                         atomic_action=False)
+        for hypervisor in hypervisors:
+            self._search_hypervisors(hypervisor.hypervisor_hostname)
