@@ -24,10 +24,11 @@ from rally.task import validation
 """Scenarios for Nova keypairs."""
 
 
-@validation.required_services(consts.Service.NOVA)
-@validation.required_openstack(users=True)
-@scenario.configure(context={"cleanup": ["nova"]},
-                    name="NovaKeypair.create_and_list_keypairs")
+@validation.add("required_services", services=[consts.Service.NOVA])
+@validation.add("required_platform", platform="openstack", users=True)
+@scenario.configure(context={"cleanup@openstack": ["nova"]},
+                    name="NovaKeypair.create_and_list_keypairs",
+                    platform="openstack")
 class CreateAndListKeypairs(utils.NovaScenario):
 
     def run(self, **kwargs):
@@ -45,10 +46,11 @@ class CreateAndListKeypairs(utils.NovaScenario):
         self.assertIn(keypair_name, [i.id for i in list_keypairs])
 
 
-@validation.required_services(consts.Service.NOVA)
-@validation.required_openstack(users=True)
-@scenario.configure(context={"cleanup": ["nova"]},
-                    name="NovaKeypair.create_and_delete_keypair")
+@validation.add("required_services", services=[consts.Service.NOVA])
+@validation.add("required_platform", platform="openstack", users=True)
+@scenario.configure(context={"cleanup@openstack": ["nova"]},
+                    name="NovaKeypair.create_and_delete_keypair",
+                    platform="openstack")
 class CreateAndDeleteKeypair(utils.NovaScenario):
 
     def run(self, **kwargs):
@@ -65,11 +67,13 @@ class CreateAndDeleteKeypair(utils.NovaScenario):
 
 @types.convert(image={"type": "glance_image"},
                flavor={"type": "nova_flavor"})
-@validation.image_valid_on_flavor("flavor", "image")
-@validation.required_services(consts.Service.NOVA)
-@validation.required_openstack(users=True)
-@scenario.configure(context={"cleanup": ["nova"]},
-                    name="NovaKeypair.boot_and_delete_server_with_keypair")
+@validation.add("image_valid_on_flavor", flavor_param="flavor",
+                image_param="image")
+@validation.add("required_services", services=[consts.Service.NOVA])
+@validation.add("required_platform", platform="openstack", users=True)
+@scenario.configure(context={"cleanup@openstack": ["nova"]},
+                    name="NovaKeypair.boot_and_delete_server_with_keypair",
+                    platform="openstack")
 class BootAndDeleteServerWithKeypair(utils.NovaScenario):
 
     @logging.log_deprecated_args(
@@ -103,10 +107,11 @@ class BootAndDeleteServerWithKeypair(utils.NovaScenario):
         self._delete_keypair(keypair)
 
 
-@validation.required_services(consts.Service.NOVA)
-@validation.required_openstack(users=True)
-@scenario.configure(context={"cleanup": ["nova"]},
-                    name="NovaKeypair.create_and_get_keypair")
+@validation.add("required_services", services=[consts.Service.NOVA])
+@validation.add("required_platform", platform="openstack", users=True)
+@scenario.configure(context={"cleanup@openstack": ["nova"]},
+                    name="NovaKeypair.create_and_get_keypair",
+                    platform="openstack")
 class CreateAndGetKeypair(utils.NovaScenario):
 
     def run(self, **kwargs):
