@@ -21,10 +21,12 @@ from rally.task import validation
 """Scenarios for quotas."""
 
 
-@validation.required_services(consts.Service.NOVA)
-@validation.required_openstack(admin=True, users=True)
-@scenario.configure(context={"admin_cleanup": ["nova.quotas"]},
-                    name="Quotas.nova_update")
+@validation.add("required_services", services=[consts.Service.NOVA])
+@validation.add("required_platform", platform="openstack",
+                admin=True, users=True)
+@scenario.configure(context={"admin_cleanup@openstack": ["nova.quotas"]},
+                    name="Quotas.nova_update",
+                    platform="openstack")
 class NovaUpdate(utils.QuotasScenario):
 
     def run(self, max_quota=1024):
@@ -37,10 +39,11 @@ class NovaUpdate(utils.QuotasScenario):
                             max_quota)
 
 
-@validation.required_services(consts.Service.NOVA)
-@validation.required_openstack(admin=True, users=True)
-@scenario.configure(context={"admin_cleanup": ["nova.quotas"]},
-                    name="Quotas.nova_update_and_delete")
+@validation.add("required_services", services=[consts.Service.NOVA])
+@validation.add("required_platform", platform="openstack",
+                admin=True, users=True)
+@scenario.configure(context={"admin_cleanup@openstack": ["nova.quotas"]},
+                    name="Quotas.nova_update_and_delete", platform="openstack")
 class NovaUpdateAndDelete(utils.QuotasScenario):
 
     def run(self, max_quota=1024):
@@ -54,10 +57,11 @@ class NovaUpdateAndDelete(utils.QuotasScenario):
         self._delete_quotas("nova", self.context["tenant"]["id"])
 
 
-@validation.required_services(consts.Service.CINDER)
-@validation.required_openstack(admin=True, users=True)
-@scenario.configure(context={"admin_cleanup": ["cinder.quotas"]},
-                    name="Quotas.cinder_update")
+@validation.add("required_services", services=[consts.Service.CINDER])
+@validation.add("required_platform", platform="openstack",
+                admin=True, users=True)
+@scenario.configure(context={"admin_cleanup@openstack": ["cinder.quotas"]},
+                    name="Quotas.cinder_update", platform="openstack")
 class CinderUpdate(utils.QuotasScenario):
 
     def run(self, max_quota=1024):
@@ -70,10 +74,11 @@ class CinderUpdate(utils.QuotasScenario):
                             max_quota)
 
 
-@validation.required_services(consts.Service.CINDER)
-@validation.required_openstack(admin=True, users=True)
-@scenario.configure(context={"admin_cleanup": ["cinder.quotas"]},
-                    name="Quotas.cinder_get")
+@validation.add("required_services", services=[consts.Service.CINDER])
+@validation.add("required_platform", platform="openstack",
+                admin=True, users=True)
+@scenario.configure(context={"admin_cleanup@openstack": ["cinder.quotas"]},
+                    name="Quotas.cinder_get", platform="openstack")
 class CinderGet(utils.QuotasScenario):
 
     def run(self):
@@ -85,10 +90,12 @@ class CinderGet(utils.QuotasScenario):
         self._get_quotas("cinder", self.context["tenant"]["id"])
 
 
-@validation.required_services(consts.Service.CINDER)
-@validation.required_openstack(admin=True, users=True)
-@scenario.configure(context={"admin_cleanup": ["cinder.quotas"]},
-                    name="Quotas.cinder_update_and_delete")
+@validation.add("required_services", services=[consts.Service.CINDER])
+@validation.add("required_platform", platform="openstack",
+                admin=True, users=True)
+@scenario.configure(context={"admin_cleanup@openstack": ["cinder.quotas"]},
+                    name="Quotas.cinder_update_and_delete",
+                    platform="openstack")
 class CinderUpdateAndDelete(utils.QuotasScenario):
 
     def run(self, max_quota=1024):
@@ -102,10 +109,12 @@ class CinderUpdateAndDelete(utils.QuotasScenario):
         self._delete_quotas("cinder", self.context["tenant"]["id"])
 
 
-@validation.required_services(consts.Service.NEUTRON)
-@validation.required_openstack(admin=True, users=True)
-@scenario.configure(context={"admin_cleanup": ["neutron.quota"]},
-                    name="Quotas.neutron_update")
+@validation.add("required_services",
+                services=[consts.Service.NEUTRON])
+@validation.add("required_platform", platform="openstack",
+                admin=True, users=True)
+@scenario.configure(context={"admin_cleanup@openstack": ["neutron.quota"]},
+                    name="Quotas.neutron_update", platform="openstack")
 class NeutronUpdate(utils.QuotasScenario):
 
     def run(self, max_quota=1024):
@@ -119,10 +128,11 @@ class NeutronUpdate(utils.QuotasScenario):
                             max_quota, quota_update_fn)
 
 
-@validation.required_services(consts.Service.NOVA)
-@validation.required_openstack(admin=True, users=True)
-@scenario.configure(context={"admin_cleanup": ["nova.quotas"]},
-                    name="Quotas.nova_get")
+@validation.add("required_services", services=[consts.Service.NOVA])
+@validation.add("required_platform", platform="openstack",
+                admin=True, users=True)
+@scenario.configure(context={"admin_cleanup@openstack": ["nova.quotas"]},
+                    name="Quotas.nova_get", platform="openstack")
 class NovaGet(utils.QuotasScenario):
 
     def run(self):
