@@ -14,18 +14,21 @@
 #    under the License.
 
 import json
+import os
 import pkgutil
 
 from rally.common import logging
 from rally.common import sshutils
+from rally.common import validation
 from rally import consts
 from rally import exceptions
+from rally.plugins.common import validators
 from rally.plugins.openstack import scenario
+from rally.plugins.openstack.scenarios.cinder import utils as cinder_utils
 from rally.plugins.openstack.scenarios.vm import utils as vm_utils
 from rally.plugins.openstack.services import heat
 from rally.task import atomic
 from rally.task import types
-from rally.task import validation
 
 
 """Scenarios that are to be run inside VM instances."""
@@ -34,21 +37,104 @@ from rally.task import validation
 LOG = logging.getLogger(__name__)
 
 
+# TODO(andreykurilin): replace by advanced jsonschema(lollipop?!) someday
+@validation.configure(name="valid_command", platform="openstack")
+class ValidCommandValidator(validators.FileExistsValidator):
+
+    def __init__(self, param_name, required=True):
+        """Checks that parameter is a proper command-specifying dictionary.
+
+        Ensure that the command dictionary is a proper command-specifying
+        dictionary described in `vmtasks.VMTasks.boot_runcommand_delete'
+        docstring.
+
+        :param param_name: Name of parameter to validate
+        :param required: Boolean indicating that the command dictionary is
+            required
+        """
+        super(ValidCommandValidator, self).__init__(param_name=param_name)
+
+        self.required = required
+
+    def check_command_dict(self, command):
+        """Check command-specifying dict `command'
+
+        :raises ValueError: on error
+        """
+
+        if not isinstance(command, dict):
+            self.fail("Command must be a dictionary")
+
+        # NOTE(pboldin): Here we check for the values not for presence of the
+        # keys due to template-driven configuration generation that can leave
+        # keys defined but values empty.
+        if command.get("interpreter"):
+            script_file = command.get("script_file")
+            if script_file:
+                if "script_inline" in command:
+                    self.fail(
+                        "Exactly one of script_inline or script_file with "
+                        "interpreter is expected: %r" % command)
+            # User tries to upload a shell? Make sure it is same as interpreter
+            interpreter = command.get("interpreter")
+            interpreter = (interpreter[-1]
+                           if isinstance(interpreter, (tuple, list))
+                           else interpreter)
+            if (command.get("local_path") and
+                    command.get("remote_path") != interpreter):
+                self.fail(
+                    "When uploading an interpreter its path should be as well"
+                    " specified as the `remote_path' string: %r" % command)
+        elif not command.get("remote_path"):
+            # No interpreter and no remote command to execute is given
+            self.fail(
+                "Supplied dict specifies no command to execute, either "
+                "interpreter or remote_path is required: %r" % command)
+
+        unexpected_keys = set(command) - {"script_file", "script_inline",
+                                          "interpreter", "remote_path",
+                                          "local_path", "command_args"}
+        if unexpected_keys:
+            self.fail(
+                "Unexpected command parameters: %s" % ", ".join(
+                    unexpected_keys))
+
+    def validate(self, context, config, plugin_cls, plugin_cfg):
+        command = config.get("args", {}).get(self.param_name)
+        if command is None and not self.required:
+            return
+
+        try:
+            self.check_command_dict(command)
+        except ValueError as e:
+            return self.fail(str(e))
+
+        for key in "script_file", "local_path":
+            if command.get(key):
+                self._file_access_ok(
+                    filename=command[key], mode=os.R_OK,
+                    param_name=self.param_name, required=self.required)
+
+
 @types.convert(image={"type": "glance_image"},
                flavor={"type": "nova_flavor"})
-@validation.image_valid_on_flavor("flavor", "image", fail_on_404_image=False)
-@validation.valid_command("command")
-@validation.number("port", minval=1, maxval=65535, nullable=True,
-                   integer_only=True)
-@validation.external_network_exists("floating_network")
-@validation.required_param_or_context(arg_name="image",
-                                      ctx_name="image_command_customizer")
-@validation.required_services(consts.Service.NOVA, consts.Service.CINDER)
-@validation.required_openstack(users=True)
-@scenario.configure(context={"cleanup": ["nova", "cinder"],
-                             "keypair": {}, "allow_ssh": None},
-                    name="VMTasks.boot_runcommand_delete")
-class BootRuncommandDelete(vm_utils.VMScenario):
+@validation.add("image_valid_on_flavor", flavor_param="flavor",
+                image_param="image", fail_on_404_image=False)
+@validation.add("valid_command", param_name="command")
+@validation.add("number", param_name="port", minval=1, maxval=65535,
+                nullable=True, integer_only=True)
+@validation.add("external_network_exists", param_name="floating_network")
+@validation.add("required_services", services=[consts.Service.NOVA,
+                                               consts.Service.CINDER])
+@validation.add("required_param_or_context",
+                param_name="image", ctx_name="image_command_customizer")
+@validation.add("required_platform", platform="openstack", users=True)
+@scenario.configure(context={"cleanup@openstack": ["nova", "cinder"],
+                             "keypair@openstack": {},
+                             "allow_ssh@openstack": None},
+                    name="VMTasks.boot_runcommand_delete",
+                    platform="openstack")
+class BootRuncommandDelete(vm_utils.VMScenario, cinder_utils.CinderBasic):
 
     def run(self, flavor, username, password=None,
             image=None,
@@ -136,15 +222,13 @@ class BootRuncommandDelete(vm_utils.VMScenario):
         :param use_floating_ip: bool, floating or fixed IP for SSH connection
         :param force_delete: whether to use force_delete for servers
         :param wait_for_ping: whether to check connectivity on server creation
-        :param **kwargs: extra arguments for booting the server
         :param max_log_length: The number of tail nova console-log lines user
                                would like to retrieve
-        :returns: dictionary with keys `data' and `errors':
-                  data: dict, JSON output from the script
-                  errors: str, raw data from the script's stderr stream
+        :param kwargs: extra arguments for booting the server
         """
         if volume_args:
-            volume = self._create_volume(volume_args["size"], imageRef=None)
+            volume = self.cinder.create_volume(volume_args["size"],
+                                               imageRef=None)
             kwargs["block_device_mapping"] = {"vdrally": "%s:::1" % volume.id}
 
         if not image:
@@ -182,7 +266,7 @@ class BootRuncommandDelete(vm_utils.VMScenario):
                 exceptions.SSHTimeout):
             console_logs = self._get_server_console_output(server,
                                                            max_log_length)
-            LOG.debug("VM console logs:\n%s", console_logs)
+            LOG.debug("VM console logs:\n%s" % console_logs)
             raise
 
         finally:
@@ -201,8 +285,8 @@ class BootRuncommandDelete(vm_utils.VMScenario):
                                       "data": text_area_output})
 
 
-@scenario.configure(context={"cleanup": ["nova", "heat"],
-                             "keypair": {}, "network": {}},
+@scenario.configure(context={"cleanup@openstack": ["nova", "heat"],
+                             "keypair@openstack": {}, "network@openstack": {}},
                     name="VMTasks.runcommand_heat")
 class RuncommandHeat(vm_utils.VMScenario):
 
@@ -354,7 +438,7 @@ EOF
 additive_dd() {
     local c=${1:-50} # Megabytes
     local file=/tmp/dd_test.img
-    local write=$(get_seconds "dd if=/dev/urandom of=${file} bs=1M count=${c}")
+    local write=$(get_seconds "dd if=/dev/zero of=${file} bs=1M count=${c}")
     local read=$(get_seconds "dd if=${file} of=/dev/null bs=1M count=${c}")
     local gzip=$(get_seconds "gzip ${file}")
     rm ${file}.gz
@@ -391,23 +475,60 @@ EOF
 
 @types.convert(image={"type": "glance_image"},
                flavor={"type": "nova_flavor"})
-@validation.image_valid_on_flavor("flavor", "image")
-@validation.valid_command("command")
-@validation.number("port", minval=1, maxval=65535, nullable=True,
-                   integer_only=True)
-@validation.external_network_exists("floating_network")
-@validation.required_services(consts.Service.NOVA, consts.Service.CINDER)
-@validation.required_openstack(users=True)
-@scenario.configure(context={"cleanup": ["nova", "cinder"],
-                             "keypair": {}, "allow_ssh": None},
-                    name="VMTasks.dd_load_test")
+@validation.add("image_valid_on_flavor", flavor_param="flavor",
+                image_param="image")
+@validation.add("number", param_name="port", minval=1, maxval=65535,
+                nullable=True, integer_only=True)
+@validation.add("external_network_exists", param_name="floating_network")
+@validation.add("required_services", services=[consts.Service.NOVA,
+                                               consts.Service.CINDER])
+@validation.add("required_platform", platform="openstack", users=True)
+@scenario.configure(context={"cleanup@openstack": ["nova", "cinder"],
+                             "keypair@openstack": {},
+                             "allow_ssh@openstack": None},
+                    name="VMTasks.dd_load_test",
+                    platform="openstack")
 class DDLoadTest(BootRuncommandDelete):
+    @logging.log_deprecated_args(
+        "Use 'interpreter' to specify the interpreter to execute script from.",
+        "0.10.0", ["command"], once=True)
+    def run(self, flavor, username, password=None,
+            image=None, command=None, interpreter="/bin/sh",
+            volume_args=None, floating_network=None, port=22,
+            use_floating_ip=True, force_delete=False, wait_for_ping=True,
+            max_log_length=None, **kwargs):
+        """Boot a server from a custom image and performs dd load test.
 
-    def run(self, command, **kwargs):
-        """Boot a server from a custom image, run a command that outputs JSON.
+        NOTE: dd load test is prepared script by Rally team. It checks
+            writing and reading metrics from the VM.
 
-        Example Script in rally-jobs/extra/install_benchmark.sh
-        :param command: default parameter from scenario
+        :param image: glance image name to use for the vm. Optional
+            in case of specified "image_command_customizer" context
+        :param flavor: VM flavor name
+        :param username: ssh username on server, str
+        :param password: Password on SSH authentication
+        :param interpreter: the interpreter to execute script with dd load test
+            (defaults to /bin/sh)
+        :param command: DEPRECATED. use interpreter instead.
+        :param volume_args: volume args for booting server from volume
+        :param floating_network: external network name, for floating ip
+        :param port: ssh port for SSH connection
+        :param use_floating_ip: bool, floating or fixed IP for SSH connection
+        :param force_delete: whether to use force_delete for servers
+        :param wait_for_ping: whether to check connectivity on server creation
+        :param max_log_length: The number of tail nova console-log lines user
+                               would like to retrieve
+        :param kwargs: extra arguments for booting the server
         """
-        command["script_inline"] = BASH_DD_LOAD_TEST
-        return super(DDLoadTest, self).run(command=command, **kwargs)
+        cmd = {"interpreter": interpreter,
+               "script_inline": BASH_DD_LOAD_TEST}
+        if command and "interpreter" in command:
+            cmd["interpreter"] = command["interpreter"]
+        return super(DDLoadTest, self).run(
+            flavor=flavor, username=username, password=password,
+            image=image, command=cmd,
+            volume_args=volume_args, floating_network=floating_network,
+            port=port, use_floating_ip=use_floating_ip,
+            force_delete=force_delete,
+            wait_for_ping=wait_for_ping, max_log_length=max_log_length,
+            **kwargs)
