@@ -21,7 +21,6 @@ import sys
 
 import six
 
-from rally.common.i18n import _LE, _LI
 from rally.common.io import subunit_v2
 from rally.common import logging
 from rally.common.plugin import plugin
@@ -33,8 +32,8 @@ from rally.verification import utils
 LOG = logging.getLogger(__name__)
 
 URL_RE = re.compile(
-    r"^(?:http|ftp)s?://"  # http:// or https://
-    r"(?:(?:[A-Z0-9](?:[A-Z0-9-]{0,61}[A-Z0-9])?\.)+"  # domain
+    r"^(?:(?:http|ftp)s?|ssh)://"  # http:// or https://
+    r"(?:(?:[A-Z0-9](?:[A-Z0-9@-]{0,61}[A-Z0-9])?\.)+"  # domain
     r"(?:[A-Z]{2,6}\.?|[A-Z0-9-]{2,}\.?)|"  # domain
     r"localhost|"  # localhost
     r"\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3})"  # IP
@@ -43,25 +42,26 @@ URL_RE = re.compile(
 
 
 class VerifierSetupFailure(exceptions.RallyException):
+    error_code = 533
     msg_fmt = "Failed to set up verifier '%(verifier)s': %(message)s"
 
 
-def configure(name, namespace="default", default_repo=None,
+def configure(name, platform="default", default_repo=None,
               default_version=None, context=None):
     """Decorator to configure plugin's attributes.
 
     :param name: Plugin name that is used for searching purpose
-    :param namespace: Plugin namespace
+    :param platform: Plugin platform
     :param default_repo: Default repository to clone
     :param default_version: Default version to checkout
     :param context: List of contexts that should be executed for verification
     """
-    def decorator(plugin):
-        plugin._configure(name, namespace)
-        plugin._meta_set("default_repo", default_repo)
-        plugin._meta_set("default_version", default_version)
-        plugin._meta_set("context", context or {})
-        return plugin
+    def decorator(plugin_inst):
+        plugin_inst = plugin.configure(name, platform=platform)(plugin_inst)
+        plugin_inst._meta_set("default_repo", default_repo)
+        plugin_inst._meta_set("default_version", default_version)
+        plugin_inst._meta_set("context", context or {})
+        return plugin_inst
 
     return decorator
 
@@ -195,10 +195,10 @@ class VerifierManager(plugin.Plugin):
                                             % source)
 
         if logging.is_debug():
-            LOG.debug("Cloning verifier repo from %s into %s.", source,
-                      self.repo_dir)
+            LOG.debug("Cloning verifier repo from %s into %s."
+                      % (source, self.repo_dir))
         else:
-            LOG.info("Cloning verifier repo from %s.", source)
+            LOG.info("Cloning verifier repo from %s." % source)
 
         cmd = ["git", "clone", source, self.repo_dir]
 
@@ -258,8 +258,8 @@ class VerifierManager(plugin.Plugin):
 
         LOG.info("Creating virtual environment. It may take a few minutes.")
 
-        LOG.debug("Initializing virtual environment in %s directory.",
-                  self.venv_dir)
+        LOG.debug("Initializing virtual environment in %s directory."
+                  % self.venv_dir)
         utils.check_output(["virtualenv", "-p", sys.executable, self.venv_dir],
                            cwd=self.repo_dir,
                            msg_on_err="Failed to initialize virtual env "
@@ -292,7 +292,7 @@ class VerifierManager(plugin.Plugin):
 
     def checkout(self, version):
         """Switch a verifier repo."""
-        LOG.info("Switching verifier repo to the '%s' version.", version)
+        LOG.info("Switching verifier repo to the '%s' version." % version)
         utils.check_output(["git", "checkout", "master"], cwd=self.repo_dir)
         utils.check_output(["git", "remote", "update"], cwd=self.repo_dir)
         utils.check_output(["git", "pull"], cwd=self.repo_dir)
@@ -308,7 +308,7 @@ class VerifierManager(plugin.Plugin):
             configuration
         """
         raise NotImplementedError(
-            _LI("'%s' verifiers don't support configuration at all.")
+            "'%s' verifiers don't support configuration at all."
             % self.get_name())
 
     def is_configured(self):
@@ -329,7 +329,7 @@ class VerifierManager(plugin.Plugin):
             configuration
         """
         raise NotImplementedError(
-            _LE("'%s' verifiers don't support configuration at all.")
+            "'%s' verifiers don't support configuration at all."
             % self.get_name())
 
     def extend_configuration(self, extra_options):
@@ -341,7 +341,7 @@ class VerifierManager(plugin.Plugin):
             configuration
         """
         raise NotImplementedError(
-            _LE("'%s' verifiers don't support configuration at all.")
+            "'%s' verifiers don't support configuration at all."
             % self.get_name())
 
     def install_extension(self, source, version=None, extra_settings=None):
@@ -357,7 +357,7 @@ class VerifierManager(plugin.Plugin):
             extensions
         """
         raise NotImplementedError(
-            _LE("'%s' verifiers don't support extensions.") % self.get_name())
+            "'%s' verifiers don't support extensions." % self.get_name())
 
     def list_extensions(self):
         """List all verifier extensions."""
@@ -372,7 +372,7 @@ class VerifierManager(plugin.Plugin):
             extensions
         """
         raise NotImplementedError(
-            _LE("'%s' verifiers don't support extensions.") % self.get_name())
+            "'%s' verifiers don't support extensions." % self.get_name())
 
     @abc.abstractmethod
     def list_tests(self, pattern=""):
