@@ -34,12 +34,20 @@ function setUp () {
 
     source ~/.rally/openrc admin admin
 
+    OPENSTACK_SERVICES=$(openstack service list)
+    if [[ $OPENSTACK_SERVICES == *"glance"* ]]; then
+        openstack image list
+    fi
+    if [[ $OPENSTACK_SERVICES == *"cinder"* ]]; then
+        openstack volume list --all-projects
+    fi
+    if [[ $OPENSTACK_SERVICES == *"neutron"* ]]; then
+        openstack network list
+    fi
+
     # NOTE(ikhudoshyn): Create additional users and register a new env
     # so that we could run scenarios using 'existing_users' context
     if [ "$DEVSTACK_GATE_PREPOPULATE_USERS" = "1" ]; then
-        # NOTE(andreykurilin): let's hardcode version, since we already
-        #    hardcoded arguments for users...
-        export OS_IDENTITY_API_VERSION=3
         openstack --version
 
         openstack project create rally-test-project-1
@@ -63,24 +71,27 @@ function setUp () {
 
         DEPLOYMENT_CONFIG_FILE=~/.rally/with-existing-users-config
 
-        rally deployment config > $DEPLOYMENT_CONFIG_FILE
-        sed -i '1a    "users": [\
-          {\
-              "username": "rally-test-user-1",\
-              "password": "rally-test-password-1",\
-              "project_name": "rally-test-project-1",\
-              "user_domain_name": "Default",\
-              "project_domain_name": "Default"\
-          },\
-          {\
-              "username": "rally-test-user-2",\
-              "password": "rally-test-password-2",\
-              "project_name": "rally-test-project-2",\
-              "user_domain_name": "Default",\
-              "project_domain_name": "Default"\
-          }\
-        ],\
-    ' $DEPLOYMENT_CONFIG_FILE
+        echo '
+{
+    "openstack": {
+        "users": [
+            {"username": "rally-test-user-1",
+             "password": "rally-test-password-1",
+             "project_name": "rally-test-project-1",
+             "user_domain_name": "Default",
+             "project_domain_name": "Default"
+            },
+            {"username": "rally-test-user-2",
+             "password": "rally-test-password-2",
+             "project_name": "rally-test-project-2",
+             "user_domain_name": "Default",
+             "project_domain_name": "Default"
+            }],
+        "auth_url": "'$OS_AUTH_URL'",
+        "region_name": "RegionOne"
+    }
+}
+' > $DEPLOYMENT_CONFIG_FILE
 
         rally deployment create --name devstask-with-users --filename $DEPLOYMENT_CONFIG_FILE
     fi
@@ -108,20 +119,34 @@ function run () {
 
     $PYTHON $RALLY_DIR/tests/ci/osresources.py --dump-list resources_at_start.txt
 
+    set +e
     rally --rally-debug task start --task $TASK $TASK_ARGS
+    retval=$?
+    if [[ $? -eq 1 ]]; then
+        exit $retval
+    fi
+    set -e
 
     mkdir -p rally-plot/extra
     $PYTHON $RALLY_DIR/tests/ci/render.py ci/index.html > rally-plot/extra/index.html
     cp $TASK rally-plot/task.txt
     tar -czf rally-plot/plugins.tar.gz -C $RALLY_PLUGINS_DIR .
     rally task results | python -m json.tool > rally-plot/results.json
+    rally task import --file rally-plot/results.json
     gzip -9 rally-plot/results.json
     rally task detailed > rally-plot/detailed.txt
     gzip -9 rally-plot/detailed.txt
     rally task detailed --iterations-data > rally-plot/detailed_with_iterations.txt
     gzip -9 rally-plot/detailed_with_iterations.txt
-    rally task report --out rally-plot/results.html
+    rally task report --html-static --out rally-plot/results.html
     gzip -9 rally-plot/results.html
+    rally task report --json --out rally-plot/new_results.json
+    rally task import --file rally-plot/new_results.json
+    gzip -9 rally-plot/new_results.json
+    rally task export --type junit-xml --to rally-plot/junit.xml
+    gzip -9 rally-plot/junit.xml
+    rally task export --type elastic --to rally-plot/elasticsearch.txt
+    gzip -9 rally-plot/elasticsearch.txt
 
     # NOTE(stpierre): if the sla check fails, we still want osresources.py
     # to run, so we turn off -e and save the return value
@@ -131,9 +156,14 @@ function run () {
     set -e
 
     cp resources_at_start.txt rally-plot/
-    $PYTHON $RALLY_DIR/tests/ci/osresources.py\
-        --compare-with-list resources_at_start.txt\
-            | gzip > rally-plot/resources_diff.txt.gz
+    if [ "$ZUUL_PROJECT" == "openstack/rally" ];then
+        $PYTHON $RALLY_DIR/tests/ci/osresources.py\
+            --compare-with-list resources_at_start.txt
+    else
+        $PYTHON $RALLY_DIR/tests/ci/osresources.py\
+            --compare-with-list resources_at_start.txt\
+                | gzip > rally-plot/resources_diff.txt.gz
+    fi
 
     exit $retval
-}
\ No newline at end of file
+}
