@@ -13,6 +13,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import collections
 import datetime as dt
 import json
 import uuid
@@ -67,7 +68,8 @@ class EnvCommandsTestCase(test.TestCase):
         mock_env_manager_create.assert_called_once_with(
             "test_name", {}, description="test_description", extras=None)
         mock_env_commands__show.assert_called_once_with(
-            mock_env_manager_create.return_value.data, False)
+            mock_env_manager_create.return_value.data,
+            to_json=False, only_spec=False)
 
     @mock.patch("rally.env.env_mgr.EnvManager.create")
     @mock.patch("rally.cli.commands.env.open", create=True)
@@ -97,6 +99,50 @@ class EnvCommandsTestCase(test.TestCase):
             mock.call(mock.ANY)
         ])
 
+    @mock.patch("rally.cli.commands.env.EnvCommands._show")
+    @mock.patch("rally.env.env_mgr.EnvManager.create_spec_from_sys_environ")
+    @mock.patch("rally.env.env_mgr.EnvManager.create")
+    @mock.patch("rally.cli.commands.env.open", create=True)
+    @mock.patch("rally.cli.commands.env.print")
+    def test_create_from_sys_env(
+            self, mock_print, mock_open, mock_env_manager_create,
+            mock_env_manager_create_spec_from_sys_environ,
+            mock_env_commands__show):
+        result = {
+            "spec": {"foo": mock.Mock()},
+            "discovery_details": collections.OrderedDict([
+                ("foo", {"available": True, "message": "available"}),
+                ("bar", {"available": False, "message": "not available",
+                         "traceback": "trace"})
+            ])
+        }
+        mock_env_manager_create_spec_from_sys_environ.return_value = result
+
+        self.assertEqual(
+            0, self.env.create(self.api, "n", "d", spec=None,
+                               from_sysenv=True, do_use=False))
+        self.assertEqual(
+            [
+                # check that the number of listed platforms is right
+                mock.call("Your system environment includes specifications of"
+                          " 1 platform(s)."),
+                mock.call("Discovery information:"),
+                mock.call("\t - foo : available."),
+                mock.call("\t - bar : not available."),
+                mock.call("trace")
+            ], mock_print.call_args_list)
+
+        mock_env_manager_create_spec_from_sys_environ.assert_called_once_with()
+        mock_env_manager_create.assert_called_once_with(
+            "n", result["spec"], description="d", extras=None)
+        self.assertFalse(mock_open.called)
+
+    @mock.patch("rally.cli.commands.env.print")
+    def test_create_with_incompatible_arguments(self, mock_print):
+        self.assertEqual(
+            1, self.env.create(self.api, "n", "d", spec="asd",
+                               from_sysenv=True))
+
     @mock.patch("rally.env.env_mgr.EnvManager.create")
     @mock.patch("rally.cli.commands.env.print")
     def test_create_exception(self, mock_print, mock_env_manager_create):
@@ -200,7 +246,7 @@ class EnvCommandsTestCase(test.TestCase):
             name="my best env",
             description="description")
         env_data["platforms"] = {}
-        self.env._show(env_data, False)
+        self.env._show(env_data, False, False)
         mock_print.assert_called_once_with(
             "+-------------+--------------------------------------+\n"
             "| uuid        | a77004a6-7fe5-4b75-a278-009c3c5f6b20 |\n"
@@ -214,7 +260,12 @@ class EnvCommandsTestCase(test.TestCase):
 
     @mock.patch("rally.cli.commands.env.print")
     def test__show_to_json(self, mock_print):
-        self.env._show("data", True)
+        self.env._show("data", to_json=True, only_spec=False)
+        mock_print.assert_called_once_with("\"data\"")
+
+    @mock.patch("rally.cli.commands.env.print")
+    def test__show_only_spec(self, mock_print):
+        self.env._show({"spec": "data"}, to_json=False, only_spec=True)
         mock_print.assert_called_once_with("\"data\"")
 
     @mock.patch("rally.env.env_mgr.EnvManager.get")
@@ -224,11 +275,13 @@ class EnvCommandsTestCase(test.TestCase):
         self.env.show(self.api, env_)
         mock_env_manager_get.assert_called_once_with(env_)
         mock__show.assert_called_once_with(
-            mock_env_manager_get.return_value.data, False)
+            mock_env_manager_get.return_value.data, to_json=False,
+            only_spec=False)
         mock__show.reset_mock()
         self.env.show(self.api, env_, to_json=True)
         mock__show.assert_called_once_with(
-            mock_env_manager_get.return_value.data, True)
+            mock_env_manager_get.return_value.data, to_json=True,
+            only_spec=False)
 
     @mock.patch("rally.env.env_mgr.EnvManager.get")
     @mock.patch("rally.cli.commands.env.print")
