@@ -192,19 +192,22 @@ class TaskCommandsTestCase(test.TestCase):
 
     @mock.patch("rally.cli.commands.task.version")
     @mock.patch("rally.cli.commands.task.TaskCommands.use")
-    @mock.patch("rally.cli.commands.task.TaskCommands.detailed")
+    @mock.patch("rally.cli.commands.task.TaskCommands._detailed")
     @mock.patch("rally.cli.commands.task.TaskCommands._load_and_validate_task",
                 return_value={"some": "json"})
-    def test_start(self, mock__load_and_validate_task, mock_detailed, mock_use,
-                   mock_version):
+    def test_start(self, mock__load_and_validate_task, mock__detailed,
+                   mock_use, mock_version):
         deployment_id = "e0617de9-77d1-4875-9b49-9d5789e29f20"
         task_path = "path_to_config.json"
         fake_task = fakes.FakeTask(uuid="some_new_uuid", tags=["tag"])
+        mock__detailed.return_value = 1
         self.fake_api.task.create.return_value = fake_task
         self.fake_api.task.validate.return_value = fakes.FakeTask(
             some="json", uuid="some_uuid", temporary=True)
 
-        self.task.start(self.fake_api, task_path, deployment_id, do_use=True)
+        val = self.task.start(self.fake_api, task_path,
+                              deployment_id, do_use=True)
+        self.assertEqual(2, val)
         mock_version.version_string.assert_called_once_with()
         self.fake_api.task.create.assert_called_once_with(
             deployment=deployment_id, tags=None)
@@ -216,14 +219,18 @@ class TaskCommandsTestCase(test.TestCase):
         mock__load_and_validate_task.assert_called_once_with(
             self.fake_api, task_path, args_file=None, raw_args=None)
         mock_use.assert_called_once_with(self.fake_api, "some_new_uuid")
-        mock_detailed.assert_called_once_with(self.fake_api,
-                                              task_id=fake_task["uuid"])
+        mock__detailed.assert_called_once_with(self.fake_api,
+                                               task_id=fake_task["uuid"])
+        mock__detailed.return_value = 0
+        val1 = self.task.start(self.fake_api, task_path,
+                               deployment_id, do_use=True)
+        self.assertEqual(0, val1)
 
-    @mock.patch("rally.cli.commands.task.TaskCommands.detailed")
+    @mock.patch("rally.cli.commands.task.TaskCommands._detailed")
     @mock.patch("rally.cli.commands.task.TaskCommands._load_and_validate_task",
                 return_value="some_config")
     def test_start_on_unfinished_deployment(self, mock__load_and_validate_task,
-                                            mock_detailed):
+                                            mock__detailed):
         deployment_id = "e0617de9-77d1-4875-9b49-9d5789e29f20"
         deployment_name = "xxx_name"
         task_path = "path_to_config.json"
@@ -238,13 +245,13 @@ class TaskCommandsTestCase(test.TestCase):
         self.assertEqual(1, self.task.start(self.fake_api, task_path,
                                             deployment="any",
                                             tags=["some_tag"]))
-        self.assertFalse(mock_detailed.called)
+        self.assertFalse(mock__detailed.called)
 
-    @mock.patch("rally.cli.commands.task.TaskCommands.detailed")
+    @mock.patch("rally.cli.commands.task.TaskCommands._detailed")
     @mock.patch("rally.cli.commands.task.TaskCommands._load_and_validate_task",
                 return_value="some_config")
     def test_start_with_task_args(self, mock__load_and_validate_task,
-                                  mock_detailed):
+                                  mock__detailed):
         fake_task = fakes.FakeTask(uuid="new_uuid", tags=["some_tag"])
         self.fake_api.task.create.return_value = fakes.FakeTask(
             uuid="new_uuid", tags=["some_tag"])
@@ -267,7 +274,7 @@ class TaskCommandsTestCase(test.TestCase):
             config=mock__load_and_validate_task.return_value,
             task=fake_task["uuid"],
             abort_on_sla_failure=False)
-        mock_detailed.assert_called_once_with(
+        mock__detailed.assert_called_once_with(
             self.fake_api,
             task_id=fake_task["uuid"])
         self.fake_api.task.create.assert_called_once_with(
@@ -279,10 +286,10 @@ class TaskCommandsTestCase(test.TestCase):
         self.assertRaises(exceptions.InvalidArgumentsException,
                           self.task.start, "path_to_config.json", None)
 
-    @mock.patch("rally.cli.commands.task.TaskCommands.detailed")
+    @mock.patch("rally.cli.commands.task.TaskCommands._detailed")
     @mock.patch("rally.cli.commands.task.TaskCommands._load_and_validate_task")
     def test_start_invalid_task(self, mock__load_and_validate_task,
-                                mock_detailed):
+                                mock__detailed):
         task_obj = fakes.FakeTask(temporary=False, tag="tag", uuid="uuid")
         self.fake_api.task.create.return_value = task_obj
         exc = exceptions.InvalidTaskException("foo")
@@ -313,7 +320,7 @@ class TaskCommandsTestCase(test.TestCase):
             task=task_obj["uuid"],
             abort_on_sla_failure=False)
 
-        self.assertFalse(mock_detailed.called)
+        self.assertFalse(mock__detailed.called)
 
     def test_abort(self):
         test_uuid = "17860c43-2274-498d-8669-448eff7b073f"
@@ -346,10 +353,11 @@ class TaskCommandsTestCase(test.TestCase):
     def test_detailed(self, iterations_data, has_output):
         test_uuid = "c0d874d4-7195-4fd5-8688-abe82bfad36f"
         detailed_value = {
-            "id": "task", "uuid": test_uuid, "status": "finished",
+            "id": "task", "uuid": test_uuid,
+            "pass_sla": False, "status": "finished",
             "subtasks": [{"workloads": [{
                 "name": "fake_name", "position": "fake_pos",
-                "args": "args", "context": "context", "sla": "sla",
+                "args": "args", "contexts": "context", "sla": "sla",
                 "runner": "runner", "hooks": [],
                 "statistics": {
                     "durations": {
@@ -540,7 +548,7 @@ class TaskCommandsTestCase(test.TestCase):
 
     def test_detailed_wrong_id(self):
         test_uuid = "eb290c30-38d8-4c8f-bbcc-fc8f74b004ae"
-        self.fake_api.task.get.return_value = None
+        self.fake_api.task.get.side_effect = None
         self.task.detailed(self.fake_api, test_uuid)
         self.fake_api.task.get.assert_called_once_with(
             task_id=test_uuid, detailed=True)
@@ -559,7 +567,7 @@ class TaskCommandsTestCase(test.TestCase):
                 "hooks": [],
                 "sla": {"failure_rate": {"max": 0}},
                 "sla_results": {"sla": [{"success": True}]},
-                "context": {"users": {}},
+                "contexts": {"users": {}},
                 "data": data or []}]}]}
 
     @mock.patch("rally.cli.commands.task.json.dumps")
@@ -584,7 +592,7 @@ class TaskCommandsTestCase(test.TestCase):
             lambda x: {
                 "key": {"kw": {"sla": x["sla"],
                                "args": x["args"],
-                               "context": x["context"],
+                               "context": x["contexts"],
                                "runner": fix_r(x),
                                "hooks": [{"description": "",
                                           "name": "foo",
@@ -715,142 +723,12 @@ class TaskCommandsTestCase(test.TestCase):
                                out="output.html", out_format="html")
         self.assertEqual(1, ret)
 
-    @mock.patch("rally.cli.commands.task.os.path.realpath",
-                side_effect=lambda p: "realpath_%s" % p)
-    @mock.patch("rally.cli.commands.task.open",
-                side_effect=mock.mock_open(), create=True)
-    @mock.patch("rally.cli.commands.task.plot")
-    @mock.patch("rally.cli.commands.task.webbrowser")
-    def test_old_report_one_uuid(self, mock_webbrowser,
-                                 mock_plot, mock_open, mock_realpath):
-        task_id = "eb290c30-38d8-4c8f-bbcc-fc8f74b004ae"
-        task_obj = self._make_task()
-
-        self.fake_api.task.get.return_value = task_obj
-        mock_plot.plot.return_value = "html_report"
-
-        def reset_mocks():
-            for m in (self.fake_api.task.get, mock_webbrowser,
-                      mock_plot, mock_open):
-                m.reset_mock()
-        self.task._old_report(self.fake_api, tasks=task_id,
-                              out="/tmp/%s.html" % task_id)
-        mock_open.assert_called_once_with("/tmp/%s.html" % task_id, "w+")
-        mock_plot.plot.assert_called_once_with([task_obj], include_libs=False)
-
-        mock_open.side_effect().write.assert_called_once_with("html_report")
-        self.fake_api.task.get.assert_called_once_with(
-            task_id=task_id, detailed=True)
-
-        # JUnit
-        reset_mocks()
-        self.task._old_report(self.fake_api, tasks=task_id,
-                              out="/tmp/%s.html" % task_id,
-                              out_format="junit-xml")
-        mock_open.assert_called_once_with("/tmp/%s.html" % task_id, "w+")
-        self.assertFalse(mock_plot.plot.called)
-
-        # HTML
-        reset_mocks()
-        self.task._old_report(self.fake_api, task_id, out="output.html",
-                              open_it=True, out_format="html")
-        mock_webbrowser.open_new_tab.assert_called_once_with(
-            "file://realpath_output.html")
-        mock_plot.plot.assert_called_once_with([task_obj], include_libs=False)
-
-        # HTML with embedded JS/CSS
-        reset_mocks()
-        self.task._old_report(self.fake_api, task_id, open_it=False,
-                              out="output.html", out_format="html-static")
-        self.assertFalse(mock_webbrowser.open_new_tab.called)
-        mock_plot.plot.assert_called_once_with([task_obj], include_libs=True)
-
-    @mock.patch("rally.cli.commands.task.os.path.realpath",
-                side_effect=lambda p: "realpath_%s" % p)
-    @mock.patch("rally.cli.commands.task.open",
-                side_effect=mock.mock_open(), create=True)
-    @mock.patch("rally.cli.commands.task.plot")
-    @mock.patch("rally.cli.commands.task.webbrowser")
-    def test_old_report_bunch_uuids(self, mock_webbrowser,
-                                    mock_plot, mock_open, mock_realpath):
-        tasks = ["eb290c30-38d8-4c8f-bbcc-fc8f74b004ae",
-                 "eb290c30-38d8-4c8f-bbcc-fc8f74b004af"]
-
-        task_obj = self._make_task()
-
-        self.fake_api.task.get.return_value = task_obj
-        mock_plot.plot.return_value = "html_report"
-
-        def reset_mocks():
-            for m in (self.fake_api.task.get, mock_webbrowser,
-                      mock_plot, mock_open):
-                m.reset_mock()
-        self.task._old_report(self.fake_api, tasks=tasks,
-                              out="/tmp/1_test.html")
-        mock_open.assert_called_once_with("/tmp/1_test.html", "w+")
-        mock_plot.plot.assert_called_once_with([task_obj, task_obj],
-                                               include_libs=False)
-
-        mock_open.side_effect().write.assert_called_once_with("html_report")
-        expected_get_calls = [mock.call(task_id=task, detailed=True)
-                              for task in tasks]
-        self.fake_api.task.get.assert_has_calls(
-            expected_get_calls, any_order=True)
-
-    @mock.patch("rally.cli.commands.task.os.path.exists", return_value=True)
-    @mock.patch("rally.cli.commands.task.os.path.realpath",
-                side_effect=lambda p: "realpath_%s" % p)
-    @mock.patch("rally.cli.commands.task.open", create=True)
-    @mock.patch("rally.cli.commands.task.plot")
-    def test_old_report_one_file(self, mock_plot, mock_open, mock_realpath,
-                                 mock_path_exists):
-
-        task_file = "/tmp/some_file.json"
-        task_obj = self._make_task()
-        mock_plot.plot.return_value = "html_report"
-        mock_open.side_effect = mock.mock_open()
-        self.task._load_task_results_file = mock.MagicMock(
-            return_value=[task_obj]
-        )
-
-        self.task._old_report(self.real_api, tasks=task_file,
-                              out="/tmp/1_test.html")
-
-        self.task._load_task_results_file.assert_called_once_with(
-            self.real_api, task_file)
-        expected_open_calls = [mock.call("/tmp/1_test.html", "w+")]
-        mock_open.assert_has_calls(expected_open_calls, any_order=True)
-        mock_plot.plot.assert_called_once_with([task_obj], include_libs=False)
-        mock_open.side_effect().write.assert_called_once_with("html_report")
-
-    @mock.patch("rally.cli.commands.task.os.path.exists", return_value=False)
-    @mock.patch("rally.cli.commands.task.tutils.open", create=True)
-    def test_old_report_exceptions(self, mock_open, mock_path_exists):
-        ret = self.task._old_report(self.real_api, tasks="/tmp/task.json",
-                                    out="/tmp/tmp.hsml")
-        self.assertEqual(1, ret)
-
-    @mock.patch("rally.cli.commands.task.os.path.exists", return_value=True)
-    def test_report(self, mock_path_exists):
-        self.task._old_report = mock.MagicMock()
+    def test_report(self):
         self.task.export = mock.MagicMock()
-
-        self.task.report(self.fake_api, task_id="file",
-                         out="out", open_it=False, out_format="html")
-
-        self.task._old_report.assert_called_once_with(
-            self.fake_api, tasks="file", out="out", open_it=False,
-            out_format="html"
-        )
-
-        self.task._old_report.reset_mock()
-        self.task.export.reset_mock()
-        mock_path_exists.return_value = False
-
-        self.task.report(self.fake_api, task_id="uuid",
+        self.task.report(self.fake_api, tasks="uuid",
                          out="out", open_it=False, out_format="junit-xml")
         self.task.export.assert_called_once_with(
-            self.fake_api, task_id="uuid", output_type="junit-xml",
+            self.fake_api, tasks="uuid", output_type="junit-xml",
             output_dest="out", open_it=False
         )
 
@@ -1051,9 +929,10 @@ class TaskCommandsTestCase(test.TestCase):
 
     def test_use_not_found(self):
         task_id = "ddc3f8ba-082a-496d-b18f-72cdf5c10a14"
-        exc = exceptions.TaskNotFound(uuid=task_id)
+        exc = exceptions.DBRecordNotFound(criteria="uuid: %s" % task_id,
+                                          table="tasks")
         self.fake_api.task.get.side_effect = exc
-        self.assertRaises(exceptions.TaskNotFound, self.task.use,
+        self.assertRaises(exceptions.DBRecordNotFound, self.task.use,
                           self.fake_api, task_id)
 
     @mock.patch("rally.cli.commands.task.os.path")
@@ -1066,17 +945,21 @@ class TaskCommandsTestCase(test.TestCase):
         # file
         self.fake_api.task.export.return_value = {
             "files": {"output_dest": "content"}, "open": "output_dest"}
+        mock_path.exists.side_effect = [False, True, False]
         mock_path.expanduser.return_value = "output_file"
         mock_path.realpath.return_value = "real_path"
         mock_fd = mock.mock_open()
         mock_open.side_effect = mock_fd
+        self.task._load_task_results_file = mock.MagicMock(
+            return_value=[{"task": "task_1"}, {"task": "task2"}])
 
-        self.task.export(self.fake_api, task_id="uuid",
+        self.task.export(self.fake_api, tasks=["uuid", "file"],
                          output_type="json", output_dest="output_dest",
                          open_it=True)
 
         self.fake_api.task.export.assert_called_once_with(
-            tasks_uuids=["uuid"], output_type="json",
+            tasks=["uuid"] + self.task._load_task_results_file.return_value,
+            output_type="json",
             output_dest="output_dest"
         )
         mock_open.assert_called_once_with("output_file", "w+")
@@ -1085,9 +968,10 @@ class TaskCommandsTestCase(test.TestCase):
         # print
         self.fake_api.task.export.reset_mock()
         self.fake_api.task.export.return_value = {"print": "content"}
-        self.task.export(self.fake_api, task_id="uuid", output_type="json")
+        self.task.export(self.fake_api, tasks="uuid", output_type="json")
         self.fake_api.task.export.assert_called_once_with(
-            tasks_uuids=["uuid"], output_type="json", output_dest=None
+            tasks=["uuid"],
+            output_type="json", output_dest=None
         )
         mock_print.assert_called_once_with("content")
 
@@ -1114,11 +998,12 @@ class TaskCommandsTestCase(test.TestCase):
             "id": "task",
             "uuid": test_uuid,
             "status": "finished",
+            "pass_sla": True,
             "subtasks": [{"workloads": [{
                 "name": "fake_name",
                 "position": "fake_pos",
                 "args": {}, "runner_type": "foo",
-                "runner": {}, "context": {}, "sla": {},
+                "runner": {}, "contexts": {}, "sla": {},
                 "hooks": {},
                 "load_duration": 3.2,
                 "full_duration": 3.5,
@@ -1219,7 +1104,8 @@ class TaskCommandsTestCase(test.TestCase):
             "pass_sla": True,
             "sla": {"failure_rate": {"max": 0}},
             "sla_results": {"sla": [{"success": True}]},
-            "context": {"users": {}},
+            "contexts": {"users": {}},
+            "contexts_results": [],
             "data": [{"timestamp": 1, "atomic_actions": {"foo": 1.0,
                                                          "bar": 1.0},
                       "duration": 5, "idle_duration": 0, "error": [{}]},
@@ -1249,7 +1135,7 @@ class TaskCommandsTestCase(test.TestCase):
                                         "args": {"a2", "v2"}
                                     }}],
                          "sla": workload["sla"],
-                         "context": workload["context"]}},
+                         "context": workload["contexts"]}},
              "sla": workload["sla_results"]["sla"],
              "result": workload["data"],
              "full_duration": workload["full_duration"],
@@ -1297,7 +1183,8 @@ class TaskCommandsTestCase(test.TestCase):
                 "workloads": [{
                     "args": {},
                     "name": "Foo.bar",
-                    "context": "contexts",
+                    "contexts": "contexts",
+                    "contexts_results": [],
                     "runner_type": "constant",
                     "runner": {
                         "times": 100,
