@@ -16,7 +16,6 @@
 import ddt
 from keystoneclient import exceptions as keystone_exc
 import mock
-from oslo_config import cfg
 import six
 import sqlalchemy.exc
 
@@ -24,6 +23,7 @@ from rally.cli import cliutils
 from rally.cli.commands import deployment
 from rally.cli.commands import task
 from rally.cli.commands import verify
+from rally.common import cfg
 from rally import exceptions
 from tests.unit import test
 
@@ -283,13 +283,14 @@ class CliUtilsTestCase(test.TestCase):
 
     @mock.patch("rally.api.API.check_db_revision")
     @mock.patch("rally.common.db.api.task_get",
-                side_effect=exceptions.TaskNotFound(uuid=FAKE_TASK_UUID))
+                side_effect=exceptions.DBRecordNotFound(
+                    criteria="uuid: %s" % FAKE_TASK_UUID, table="tasks"))
     def test_run_task_not_found(self, mock_task_get,
                                 mock_api_check_db_revision):
         ret = cliutils.run(["rally", "task", "status", "%s" % FAKE_TASK_UUID],
                            self.categories)
         self.assertTrue(mock_task_get.called)
-        self.assertEqual(1, ret)
+        self.assertEqual(404, ret)
 
     @mock.patch("rally.api.API.check_db_revision")
     @mock.patch("rally.cli.cliutils.validate_args",
