@@ -37,7 +37,7 @@ class EC2ServerGeneratorTestCase(test.TestCase):
         for tenant_id in tenants.keys():
             for i in range(users_per_tenant):
                 users.append({"id": i, "tenant_id": tenant_id,
-                              "credential": "credential"})
+                              "credential": mock.MagicMock()})
         return tenants, users
 
     def _get_context(self, users, tenants):
@@ -55,6 +55,7 @@ class EC2ServerGeneratorTestCase(test.TestCase):
             },
             "admin": {"credential": mock.MagicMock()},
             "task": mock.MagicMock(),
+            "owner_id": "foo_uuid",
             "users": users,
             "tenants": tenants
         }
@@ -110,4 +111,4 @@ class EC2ServerGeneratorTestCase(test.TestCase):
             names=["ec2.servers"],
             users=context["users"],
             superclass=ec2_utils.EC2Scenario,
-            task_id=context["task"]["uuid"])
+            task_id="foo_uuid")
