@@ -19,14 +19,15 @@ import ddt
 import mock
 import six
 
-from rally import consts as rally_consts
 from rally import exceptions
 from rally.plugins.openstack.context.manila import consts
 from rally.plugins.openstack.context.manila import manila_share_networks
 from tests.unit import test
 
-MANILA_UTILS_PATH = ("rally.plugins.openstack.scenarios.manila.utils."
-                     "ManilaScenario.")
+MANILA_UTILS_PATH = (
+    "rally.plugins.openstack.scenarios.manila.utils.ManilaScenario.")
+
+MOCK_USER_CREDENTIAL = mock.MagicMock()
 
 
 class Fake(object):
@@ -72,8 +73,9 @@ class ShareNetworksTestCase(test.TestCase):
         users = []
         for t_id in tenants.keys():
             for i in range(self.USERS_PER_TENANT):
-                users.append(
-                    {"id": i, "tenant_id": t_id, "credential": "fake"})
+                users.append({
+                    "id": i, "tenant_id": t_id,
+                    "credential": MOCK_USER_CREDENTIAL})
         context = {
             "config": {
                 "users": {
@@ -124,8 +126,8 @@ class ShareNetworksTestCase(test.TestCase):
                 "tenant_2_id": {"id": "tenant_2_id", "name": "tenant_2_name"},
             },
             "users": [
-                {"tenant_id": "tenant_1_id", "credential": {"c1": "foo"}},
-                {"tenant_id": "tenant_2_id", "credential": {"c2": "bar"}},
+                {"tenant_id": "tenant_1_id", "credential": mock.MagicMock()},
+                {"tenant_id": "tenant_2_id", "credential": mock.MagicMock()},
             ],
         }
         self.existing_sns = [
@@ -146,17 +148,6 @@ class ShareNetworksTestCase(test.TestCase):
         self.assertEqual(
             {"foo": "bar", "share_networks": {}, "use_share_networks": False},
             inst.config)
-        self.assertIn(
-            rally_consts.JSON_SCHEMA, inst.CONFIG_SCHEMA.get("$schema"))
-        self.assertFalse(inst.CONFIG_SCHEMA.get("additionalProperties"))
-        self.assertEqual("object", inst.CONFIG_SCHEMA.get("type"))
-        props = inst.CONFIG_SCHEMA.get("properties", {})
-        self.assertEqual({"type": "object"}, props.get("share_networks"))
-        self.assertEqual({"type": "boolean"}, props.get("use_share_networks"))
-        self.assertEqual(450, inst.get_order())
-        self.assertEqual(
-            consts.SHARE_NETWORKS_CONTEXT_NAME,
-            inst.get_name())
 
     def test_setup_share_networks_disabled(self):
         ctxt = {
@@ -166,9 +157,7 @@ class ShareNetworksTestCase(test.TestCase):
                     "use_share_networks": False,
                 },
             },
-            consts.SHARE_NETWORKS_CONTEXT_NAME: {
-                "delete_share_networks": False,
-            },
+            consts.SHARE_NETWORKS_CONTEXT_NAME: {},
         }
         inst = manila_share_networks.ShareNetworks(ctxt)
 
@@ -178,7 +167,7 @@ class ShareNetworksTestCase(test.TestCase):
 
         self.assertEqual(expected_ctxt, inst.context)
 
-    @mock.patch("rally.osclients.Clients")
+    @mock.patch("rally.plugins.openstack.osclients.Clients")
     @mock.patch(MANILA_UTILS_PATH + "_list_share_networks")
     def test_setup_use_existing_share_networks(
             self, mock_manila_scenario__list_share_networks, mock_clients):
@@ -214,8 +203,7 @@ class ShareNetworksTestCase(test.TestCase):
         self.assertEqual(expected_ctxt["task"], inst.context.get("task"))
         self.assertEqual(expected_ctxt["config"], inst.context.get("config"))
         self.assertEqual(expected_ctxt["users"], inst.context.get("users"))
-        self.assertEqual(
-            False,
+        self.assertFalse(
             inst.context.get(consts.SHARE_NETWORKS_CONTEXT_NAME, {}).get(
                 "delete_share_networks"))
         self.assertEqual(expected_ctxt["tenants"], inst.context.get("tenants"))
@@ -227,7 +215,7 @@ class ShareNetworksTestCase(test.TestCase):
 
         self.assertRaises(exceptions.ContextSetupFailure, inst.setup)
 
-    @mock.patch("rally.osclients.Clients")
+    @mock.patch("rally.plugins.openstack.osclients.Clients")
     @mock.patch(MANILA_UTILS_PATH + "_list_share_networks")
     def test_setup_use_existing_share_networks_sn_not_found(
             self, mock_manila_scenario__list_share_networks, mock_clients):
@@ -249,7 +237,7 @@ class ShareNetworksTestCase(test.TestCase):
         self.assertRaises(exceptions.ContextSetupFailure, inst.setup)
 
     @ddt.data(True, False)
-    @mock.patch("rally.osclients.Clients")
+    @mock.patch("rally.plugins.openstack.osclients.Clients")
     @mock.patch(MANILA_UTILS_PATH + "_create_share_network")
     @mock.patch(MANILA_UTILS_PATH + "_add_security_service_to_share_network")
     def test_setup_autocreate_share_networks_with_security_services(
@@ -303,11 +291,11 @@ class ShareNetworksTestCase(test.TestCase):
         ]
         mock_manila_scenario__create_share_network.assert_has_calls(
             expected_calls * (self.TENANTS_AMOUNT * networks_per_tenant))
-        mock_clients.assert_has_calls([
-            mock.call("fake", {}) for i in range(self.TENANTS_AMOUNT)])
+        mock_clients.assert_has_calls([mock.call(MOCK_USER_CREDENTIAL, {})
+                                      for i in range(self.TENANTS_AMOUNT)])
 
     @ddt.data(True, False)
-    @mock.patch("rally.osclients.Clients")
+    @mock.patch("rally.plugins.openstack.osclients.Clients")
     @mock.patch(MANILA_UTILS_PATH + "_create_share_network")
     @mock.patch(MANILA_UTILS_PATH + "_add_security_service_to_share_network")
     def test_setup_autocreate_share_networks_wo_security_services(
@@ -341,10 +329,10 @@ class ShareNetworksTestCase(test.TestCase):
         expected_calls = [mock.call(**sn_args), mock.call().to_dict()]
         mock_manila_scenario__create_share_network.assert_has_calls(
             expected_calls * (self.TENANTS_AMOUNT * networks_per_tenant))
-        mock_clients.assert_has_calls([
-            mock.call("fake", {}) for i in range(self.TENANTS_AMOUNT)])
+        mock_clients.assert_has_calls([mock.call(MOCK_USER_CREDENTIAL, {})
+                                      for i in range(self.TENANTS_AMOUNT)])
 
-    @mock.patch("rally.osclients.Clients")
+    @mock.patch("rally.plugins.openstack.osclients.Clients")
     @mock.patch(MANILA_UTILS_PATH + "_create_share_network")
     @mock.patch(MANILA_UTILS_PATH + "_add_security_service_to_share_network")
     def test_setup_autocreate_share_networks_wo_networks(
@@ -366,10 +354,10 @@ class ShareNetworksTestCase(test.TestCase):
         expected_calls = [mock.call(), mock.call().to_dict()]
         mock_manila_scenario__create_share_network.assert_has_calls(
             expected_calls * self.TENANTS_AMOUNT)
-        mock_clients.assert_has_calls([
-            mock.call("fake", {}) for i in range(self.TENANTS_AMOUNT)])
+        mock_clients.assert_has_calls([mock.call(MOCK_USER_CREDENTIAL, {})
+                                      for i in range(self.TENANTS_AMOUNT)])
 
-    @mock.patch("rally.osclients.Clients")
+    @mock.patch("rally.plugins.openstack.osclients.Clients")
     @mock.patch(MANILA_UTILS_PATH + "_delete_share_network")
     @mock.patch(MANILA_UTILS_PATH + "_list_share_servers")
     @mock.patch(MANILA_UTILS_PATH + "_list_share_networks")
@@ -393,62 +381,23 @@ class ShareNetworksTestCase(test.TestCase):
             self.assertIn(mock.call(user["credential"], {}),
                           mock_clients.mock_calls)
 
-    @ddt.data(True, False)
-    @mock.patch("rally.task.utils.wait_for_status")
-    @mock.patch("rally.osclients.Clients")
-    @mock.patch(MANILA_UTILS_PATH + "_delete_share_network")
-    @mock.patch(MANILA_UTILS_PATH + "_create_share_network")
-    @mock.patch(MANILA_UTILS_PATH + "_add_security_service_to_share_network")
-    @mock.patch(MANILA_UTILS_PATH + "_list_share_servers")
-    def test_cleanup_autocreated_share_networks(
-            self, use_security_services,
-            mock_manila_scenario__list_share_servers,
-            mock_manila_scenario__add_security_service_to_share_network,
-            mock_manila_scenario__create_share_network,
-            mock_manila_scenario__delete_share_network,
-            mock_clients,
-            mock_wait_for_status):
-        fake_share_servers = ["fake_share_server"]
-        mock_manila_scenario__list_share_servers.return_value = (
-            fake_share_servers)
-        networks_per_tenant = 2
-        ctxt = self._get_context(
-            networks_per_tenant=networks_per_tenant,
-            use_security_services=use_security_services,
-        )
-        inst = manila_share_networks.ShareNetworks(ctxt)
-        for tenant_id in list(ctxt["tenants"].keys()):
-            inst.context["tenants"][tenant_id][
-                consts.SECURITY_SERVICES_CONTEXT_NAME] = {
-                    "security_services": [
-                        Fake(id="fake_id").to_dict() for i in (1, 2, 3)
-                    ]
-            }
-        inst.setup()
+    @mock.patch("rally.plugins.openstack.context.manila.manila_share_networks."
+                "resource_manager.cleanup")
+    def test_cleanup_autocreated_share_networks(self, mock_cleanup):
+        task_id = "task"
+        ctxt = {
+            "config": {"manila_share_networks": {
+                "use_share_networks": True}},
+            "users": [mock.Mock()],
+            "task": {"uuid": task_id}}
 
-        mock_clients.assert_has_calls([
-            mock.call("fake", {}) for i in range(self.TENANTS_AMOUNT)])
+        inst = manila_share_networks.ShareNetworks(ctxt)
 
         inst.cleanup()
 
-        self.assertEqual(self.TENANTS_AMOUNT * 4, mock_clients.call_count)
-        self.assertEqual(
-            self.TENANTS_AMOUNT * networks_per_tenant,
-            mock_manila_scenario__list_share_servers.call_count)
-        mock_manila_scenario__list_share_servers.assert_has_calls(
-            [mock.call(search_opts=mock.ANY)])
-        self.assertEqual(
-            self.TENANTS_AMOUNT * networks_per_tenant,
-            mock_manila_scenario__delete_share_network.call_count)
-        self.assertEqual(
-            self.TENANTS_AMOUNT * networks_per_tenant,
-            mock_wait_for_status.call_count)
-        mock_wait_for_status.assert_has_calls([
-            mock.call(
-                fake_share_servers[0],
-                ready_statuses=["deleted"],
-                check_deletion=True,
-                update_resource=mock.ANY,
-                timeout=180,
-                check_interval=2),
-        ])
+        mock_cleanup.assert_called_once_with(
+            names=["manila.share_networks"],
+            users=ctxt["users"],
+            superclass=manila_share_networks.ShareNetworks,
+            api_versions=None,
+            task_id=task_id)
