@@ -16,7 +16,6 @@
 import mock
 
 from rally.plugins.openstack.context.murano import murano_packages
-from rally.plugins.openstack.scenarios.murano import utils as murano_utils
 from tests.unit import test
 
 CTX = "rally.plugins.openstack.context.murano.murano_packages"
@@ -47,6 +46,7 @@ class MuranoPackageGeneratorTestCase(test.TestCase):
                 "credential": mock.MagicMock()
             },
             "task": mock.MagicMock(),
+            "owner_id": "foo_uuid",
             "users": [
                 {
                     "id": "user_0",
@@ -93,8 +93,8 @@ class MuranoPackageGeneratorTestCase(test.TestCase):
         mock_cleanup.assert_called_once_with(
             names=["murano.packages"],
             users=murano_ctx.context["users"],
-            superclass=murano_utils.MuranoScenario,
-            task_id=murano_ctx.context["task"]["uuid"])
+            superclass=murano_packages.PackageGenerator,
+            task_id="foo_uuid")
 
     @mock.patch("%s.osclients" % CTX)
     @mock.patch("%s.resource_manager.cleanup" % CTX)
@@ -114,5 +114,5 @@ class MuranoPackageGeneratorTestCase(test.TestCase):
         mock_cleanup.assert_called_once_with(
             names=["murano.packages"],
             users=murano_ctx.context["users"],
-            superclass=murano_utils.MuranoScenario,
-            task_id=ctx_dict["task"]["uuid"])
+            superclass=murano_packages.PackageGenerator,
+            task_id="foo_uuid")
