@@ -20,7 +20,7 @@ from rally import exceptions
 from rally.plugins.openstack.scenarios.neutron import utils
 from tests.unit import test
 
-NEUTRON_UTILS = "rally.plugins.openstack.scenarios.neutron.utils."
+NEUTRON_UTILS = "rally.plugins.openstack.scenarios.neutron.utils"
 
 
 @ddt.ddt
@@ -45,8 +45,7 @@ class NeutronScenarioTestCase(test.ScenarioTestCase):
         self.scenario._list_networks = mock.Mock(return_value=networks)
         resultant_network_id = self.scenario._get_network_id(network)
         self.assertEqual(network_id, resultant_network_id)
-        self.scenario._list_networks.assert_called_once_with(
-            atomic_action=False)
+        self.scenario._list_networks.assert_called_once_with()
 
         self.scenario._list_networks.reset_mock()
 
@@ -54,16 +53,14 @@ class NeutronScenarioTestCase(test.ScenarioTestCase):
         network = "foo-id"
         resultant_network_id = self.scenario._get_network_id(network)
         self.assertEqual(network_id, resultant_network_id)
-        self.scenario._list_networks.assert_called_once_with(
-            atomic_action=False)
+        self.scenario._list_networks.assert_called_once_with()
         self.scenario._list_networks.reset_mock()
 
         # Invalid network-name
         network = "absent-network"
         self.assertRaises(exceptions.NotFoundException,
                           self.scenario._get_network_id, network)
-        self.scenario._list_networks.assert_called_once_with(
-            atomic_action=False)
+        self.scenario._list_networks.assert_called_once_with()
 
     def test_create_network(self):
         self.clients("neutron").create_network.return_value = self.network
@@ -83,15 +80,14 @@ class NeutronScenarioTestCase(test.ScenarioTestCase):
         self.clients("neutron").list_networks.return_value = networks_dict
 
         # without atomic action
-        return_networks_list = self.scenario._list_networks(
-            atomic_action=False)
+        return_networks_list = self.scenario._list_networks()
         self.assertEqual(networks_list, return_networks_list)
 
         # with atomic action
         return_networks_list = self.scenario._list_networks()
         self.assertEqual(networks_list, return_networks_list)
         self._test_atomic_action_timer(self.scenario.atomic_actions(),
-                                       "neutron.list_networks")
+                                       "neutron.list_networks", count=2)
 
     def test_show_network(self):
         network = {
@@ -108,6 +104,21 @@ class NeutronScenarioTestCase(test.ScenarioTestCase):
         self._test_atomic_action_timer(self.scenario.atomic_actions(),
                                        "neutron.show_network")
 
+    def test_show_router(self):
+        router = {
+            "router": {
+                "id": "fake-id",
+                "name": "fake-name",
+                "admin_state_up": False
+            }
+        }
+
+        return_router = self.scenario._show_router(router)
+        self.assertEqual(self.clients("neutron").show_router.return_value,
+                         return_router)
+        self._test_atomic_action_timer(self.scenario.atomic_actions(),
+                                       "neutron.show_router")
+
     def test_update_network(self):
         expected_network = {
             "network": {
@@ -127,7 +138,7 @@ class NeutronScenarioTestCase(test.ScenarioTestCase):
                                                        network_update_args)
         self.clients("neutron").update_network.assert_called_once_with(
             network["network"]["id"], expected_network)
-        self.assertEqual(result_network, expected_network)
+        self.assertEqual(expected_network, result_network)
         self._test_atomic_action_timer(self.scenario.atomic_actions(),
                                        "neutron.update_network")
 
@@ -138,7 +149,7 @@ class NeutronScenarioTestCase(test.ScenarioTestCase):
         self._test_atomic_action_timer(self.scenario.atomic_actions(),
                                        "neutron.delete_network")
 
-    @mock.patch(NEUTRON_UTILS + "network_wrapper")
+    @mock.patch("%s.network_wrapper" % NEUTRON_UTILS)
     def test_create_subnet(self, mock_network_wrapper):
         network_id = "fake-id"
         start_cidr = "192.168.0.0/24"
@@ -183,6 +194,15 @@ class NeutronScenarioTestCase(test.ScenarioTestCase):
         self._test_atomic_action_timer(self.scenario.atomic_actions(),
                                        "neutron.list_subnets")
 
+    def test_show_subnet(self):
+        subnet = {"subnet": {"name": "fake-name", "id": "fake-id"}}
+
+        result_subnet = self.scenario._show_subnet(subnet)
+        self.assertEqual(self.clients("neutron").show_subnet.return_value,
+                         result_subnet)
+        self._test_atomic_action_timer(self.scenario.atomic_actions(),
+                                       "neutron.show_subnet")
+
     def test_update_subnet(self):
         expected_subnet = {
             "subnet": {
@@ -201,7 +221,7 @@ class NeutronScenarioTestCase(test.ScenarioTestCase):
                                                      subnet_update_args)
         self.clients("neutron").update_subnet.assert_called_once_with(
             subnet["subnet"]["id"], expected_subnet)
-        self.assertEqual(result_subnet, expected_subnet)
+        self.assertEqual(expected_subnet, result_subnet)
         self._test_atomic_action_timer(self.scenario.atomic_actions(),
                                        "neutron.update_subnet")
 
@@ -233,6 +253,8 @@ class NeutronScenarioTestCase(test.ScenarioTestCase):
         external_network = [{"id": "ext-net", "router:external": True}]
         self.scenario._list_networks = mock.Mock(return_value=external_network)
         self.clients("neutron").create_router.return_value = router
+        self.clients("neutron").list_extensions.return_value = {
+            "extensions": [{"alias": "ext-gw-mode"}]}
 
         # External_gw options
         gw_info = {"network_id": external_network[0]["id"],
@@ -253,6 +275,8 @@ class NeutronScenarioTestCase(test.ScenarioTestCase):
         external_network = [{"id": "ext-net", "router:external": False}]
         self.scenario._list_networks = mock.Mock(return_value=external_network)
         self.clients("neutron").create_router.return_value = router
+        self.clients("neutron").list_extensions.return_value = {
+            "extensions": [{"alias": "ext-gw-mode"}]}
 
         # External_gw options with no external networks in list_networks()
         result_router = self.scenario._create_router({}, external_gw=True)
@@ -263,6 +287,27 @@ class NeutronScenarioTestCase(test.ScenarioTestCase):
         self._test_atomic_action_timer(self.scenario.atomic_actions(),
                                        "neutron.create_router")
 
+    def test_create_router_with_ext_gw_but_no_ext_gw_mode_extension(self):
+        router = mock.Mock()
+        external_network = [{"id": "ext-net", "router:external": True}]
+        self.scenario._list_networks = mock.Mock(return_value=external_network)
+        self.clients("neutron").create_router.return_value = router
+        self.clients("neutron").list_extensions.return_value = {
+            "extensions": []}
+
+        # External_gw options
+        gw_info = {"network_id": external_network[0]["id"]}
+        router_data = {
+            "name": self.scenario.generate_random_name.return_value,
+            "external_gateway_info": gw_info
+        }
+        result_router = self.scenario._create_router({}, external_gw=True)
+        self.clients("neutron").create_router.assert_called_once_with(
+            {"router": router_data})
+        self.assertEqual(result_router, router)
+        self._test_atomic_action_timer(
+            self.scenario.atomic_actions(), "neutron.create_router")
+
     def test_create_router_explicit(self):
         router = mock.Mock()
         self.clients("neutron").create_router.return_value = router
@@ -317,7 +362,7 @@ class NeutronScenarioTestCase(test.ScenarioTestCase):
                                                      router_update_args)
         self.clients("neutron").update_router.assert_called_once_with(
             router["router"]["id"], expected_router)
-        self.assertEqual(result_router, expected_router)
+        self.assertEqual(expected_router, result_router)
         self._test_atomic_action_timer(self.scenario.atomic_actions(),
                                        "neutron.update_router")
 
@@ -341,9 +386,71 @@ class NeutronScenarioTestCase(test.ScenarioTestCase):
         self._test_atomic_action_timer(self.scenario.atomic_actions(),
                                        "neutron.remove_interface_router")
 
+    def test_add_gateway_router(self):
+        ext_net = {
+            "network": {
+                "name": "extnet-name",
+                "id": "extnet-id"
+            }
+        }
+        router = {
+            "router": {
+                "name": "router-name",
+                "id": "router-id"
+            }
+        }
+        enable_snat = "fake_snat"
+        gw_info = {"network_id": ext_net["network"]["id"],
+                   "enable_snat": enable_snat}
+        self.clients("neutron").list_extensions.return_value = {
+            "extensions": [{"alias": "ext-gw-mode"}]}
+
+        self.scenario._add_gateway_router(router, ext_net, enable_snat)
+        self.clients("neutron").add_gateway_router.assert_called_once_with(
+            router["router"]["id"], gw_info)
+        self._test_atomic_action_timer(self.scenario.atomic_actions(),
+                                       "neutron.add_gateway_router")
+
+    def test_add_gateway_router_without_ext_gw_mode_extension(self):
+        ext_net = {
+            "network": {
+                "name": "extnet-name",
+                "id": "extnet-id"
+            }
+        }
+        router = {
+            "router": {
+                "name": "router-name",
+                "id": "router-id"
+            }
+        }
+        enable_snat = "fake_snat"
+        gw_info = {"network_id": ext_net["network"]["id"]}
+        self.clients("neutron").list_extensions.return_value = {
+            "extensions": {}}
+
+        self.scenario._add_gateway_router(router, ext_net, enable_snat)
+        self.clients("neutron").add_gateway_router.assert_called_once_with(
+            router["router"]["id"], gw_info)
+        self._test_atomic_action_timer(self.scenario.atomic_actions(),
+                                       "neutron.add_gateway_router")
+
+    def test_remove_gateway_router(self):
+        router = {
+            "router": {
+                "name": "router-name",
+                "id": "router-id"
+            }
+        }
+        self.scenario._remove_gateway_router(router)
+        self.clients("neutron").remove_gateway_router.assert_called_once_with(
+            router["router"]["id"])
+        self._test_atomic_action_timer(self.scenario.atomic_actions(),
+                                       "neutron.remove_gateway_router")
+
     def test_SUBNET_IP_VERSION(self):
         """Curent NeutronScenario implementation supports only IPv4."""
-        self.assertEqual(utils.NeutronScenario.SUBNET_IP_VERSION, 4)
+        self.assertEqual(4, utils.NeutronScenario.SUBNET_IP_VERSION)
 
     def test_create_port(self):
         net_id = "network-id"
@@ -379,6 +486,21 @@ class NeutronScenarioTestCase(test.ScenarioTestCase):
         self._test_atomic_action_timer(self.scenario.atomic_actions(),
                                        "neutron.list_ports")
 
+    def test_show_port(self):
+        expect_port = {
+            "port": {
+                "id": "port-id",
+                "name": "port-name",
+                "admin_state_up": True
+            }
+        }
+        self.clients("neutron").show_port.return_value = expect_port
+        self.assertEqual(expect_port, self.scenario._show_port(expect_port))
+        self.clients("neutron").show_port.assert_called_once_with(
+            expect_port["port"]["id"])
+        self._test_atomic_action_timer(self.scenario.atomic_actions(),
+                                       "neutron.show_port")
+
     def test_update_port(self):
         expected_port = {
             "port": {
@@ -404,7 +526,7 @@ class NeutronScenarioTestCase(test.ScenarioTestCase):
         result_port = self.scenario._update_port(port, port_update_args)
         self.clients("neutron").update_port.assert_called_once_with(
             port["port"]["id"], expected_port)
-        self.assertEqual(result_port, expected_port)
+        self.assertEqual(expected_port, result_port)
         self._test_atomic_action_timer(self.scenario.atomic_actions(),
                                        "neutron.update_port")
 
@@ -445,8 +567,8 @@ class NeutronScenarioTestCase(test.ScenarioTestCase):
             self.scenario._create_network.assert_called_once_with(
                 network_create_args or {})
 
-    @mock.patch(NEUTRON_UTILS + "NeutronScenario._create_subnet")
-    @mock.patch(NEUTRON_UTILS + "NeutronScenario._create_network")
+    @mock.patch("%s.NeutronScenario._create_subnet" % NEUTRON_UTILS)
+    @mock.patch("%s.NeutronScenario._create_network" % NEUTRON_UTILS)
     def test_create_network_and_subnets(self,
                                         mock__create_network,
                                         mock__create_subnet):
@@ -543,7 +665,7 @@ class NeutronScenarioTestCase(test.ScenarioTestCase):
                                                          subnet_cidr_start,
                                                          subnets_per_network,
                                                          router_create_args)
-        self.assertEqual(actual, (network, subnets, routers))
+        self.assertEqual((network, subnets, routers), actual)
         self.scenario._create_network.assert_called_once_with(
             network_create_args or {})
         self.scenario._create_subnets.assert_called_once_with(
@@ -582,7 +704,7 @@ class NeutronScenarioTestCase(test.ScenarioTestCase):
                             "fakearg": "fake"}
 
         result_pool = self.scenario._update_v1_pool(pool, **pool_update_args)
-        self.assertEqual(result_pool, expected_pool)
+        self.assertEqual(expected_pool, result_pool)
         self.clients("neutron").update_pool.assert_called_once_with(
             pool["pool"]["id"], expected_pool)
         self._test_atomic_action_timer(self.scenario.atomic_actions(),
@@ -627,13 +749,13 @@ class NeutronScenarioTestCase(test.ScenarioTestCase):
         vip_update_args = {"name": "foo", "admin_state_up": False}
 
         result_vip = self.scenario._update_v1_vip(vip, **vip_update_args)
-        self.assertEqual(result_vip, expected_vip)
+        self.assertEqual(expected_vip, result_vip)
         self.clients("neutron").update_vip.assert_called_once_with(
             vip["vip"]["id"], expected_vip)
         self._test_atomic_action_timer(self.scenario.atomic_actions(),
                                        "neutron.update_vip")
 
-    @mock.patch(NEUTRON_UTILS + "NeutronScenario.generate_random_name")
+    @mock.patch("%s.NeutronScenario.generate_random_name" % NEUTRON_UTILS)
     def test_create_security_group(self, mock_generate_random_name):
         security_group_create_args = {"description": "Fake security group"}
         expected_security_group = {
@@ -670,6 +792,17 @@ class NeutronScenarioTestCase(test.ScenarioTestCase):
         self._test_atomic_action_timer(self.scenario.atomic_actions(),
                                        "neutron.list_security_groups")
 
+    def test_show_security_group(self):
+        security_group = {"security_group": {"id": "fake-id"}}
+        result = self.scenario._show_security_group(security_group)
+        self.assertEqual(
+            result,
+            self.clients("neutron").show_security_group.return_value)
+        self.clients("neutron").show_security_group.assert_called_once_with(
+            security_group["security_group"]["id"])
+        self._test_atomic_action_timer(self.scenario.atomic_actions(),
+                                       "neutron.show_security_group")
+
     def test_delete_security_group(self):
         security_group = {"security_group": {"id": "fake-id"}}
         self.scenario._delete_security_group(security_group)
@@ -703,10 +836,68 @@ class NeutronScenarioTestCase(test.ScenarioTestCase):
                 "description": "Updated",
                 "name": self.scenario.generate_random_name.return_value}}
         )
-        self.assertEqual(result_security_group, expected_security_group)
+        self.assertEqual(expected_security_group, result_security_group)
         self._test_atomic_action_timer(self.scenario.atomic_actions(),
                                        "neutron.update_security_group")
 
+    def test_create_security_group_rule(self):
+        security_group_rule_args = {"description": "Fake Rule"}
+        expected_security_group_rule = {
+            "security_group_rule": {
+                "id": "fake-id",
+                "security_group_id": "security-group-id",
+                "direction": "ingress",
+                "description": "Fake Rule"
+            }
+        }
+        client = self.clients("neutron")
+        client.create_security_group_rule = mock.Mock(
+            return_value=expected_security_group_rule)
+
+        security_group_rule_data = {
+            "security_group_rule":
+                {"security_group_id": "security-group-id",
+                 "direction": "ingress",
+                 "description": "Fake Rule"}
+        }
+        result_security_group_rule = self.scenario._create_security_group_rule(
+            "security-group-id", **security_group_rule_args)
+        self.assertEqual(expected_security_group_rule,
+                         result_security_group_rule)
+        client.create_security_group_rule.assert_called_once_with(
+            security_group_rule_data)
+        self._test_atomic_action_timer(self.scenario.atomic_actions(),
+                                       "neutron.create_security_group_rule")
+
+    def test_list_security_group_rules(self):
+        security_group_rules_list = [{"id": "security-group-rule-id"}]
+        security_group_rules_dict = {
+            "security_group_rules": security_group_rules_list}
+
+        self.clients("neutron").list_security_group_rules = mock.Mock(
+            return_value=security_group_rules_dict)
+        self.assertEqual(
+            self.scenario._list_security_group_rules(),
+            self.clients("neutron").list_security_group_rules.return_value)
+        self._test_atomic_action_timer(self.scenario.atomic_actions(),
+                                       "neutron.list_security_group_rules")
+
+    def test_show_security_group_rule(self):
+        return_rule = self.scenario._show_security_group_rule(1)
+        self.assertEqual(
+            self.clients("neutron").show_security_group_rule.return_value,
+            return_rule)
+
+        self._test_atomic_action_timer(self.scenario.atomic_actions(),
+                                       "neutron.show_security_group_rule")
+
+    def test_delete_security_group_rule(self):
+        self.scenario._delete_security_group_rule(1)
+        clients = self.clients("neutron")
+        clients.delete_security_group_rule.assert_called_once_with(1)
+        self._test_atomic_action_timer(self.scenario.atomic_actions(),
+                                       "neutron.delete_security_group_rule")
+
     @ddt.data(
         {"networks": [{"subnets": "subnet-id"}]},
         {"pool_create_args": None, "networks": [{"subnets": ["subnet-id"]}]},
@@ -725,12 +916,9 @@ class NeutronScenarioTestCase(test.ScenarioTestCase):
             subnets = []
             [subnets.extend(net["subnets"]) for net in networks]
             self.scenario._create_lb_pool.assert_has_calls(
-                [mock.call(subnet, atomic_action=False,
+                [mock.call(subnet,
                            **pool_create_args) for subnet in subnets])
-            self.assertEqual(resultant_pools, [pool] * len(subnets))
-            self._test_atomic_action_timer(
-                self.scenario.atomic_actions(),
-                "neutron.create_%s_pools" % len(subnets))
+            self.assertEqual([pool] * len(subnets), resultant_pools)
 
     @ddt.data(
         {"subnet_id": "foo-id"},
@@ -738,16 +926,10 @@ class NeutronScenarioTestCase(test.ScenarioTestCase):
         {"pool_create_args": {}, "subnet_id": "foo-id"},
         {"pool_create_args": {"name": "given-name"},
          "subnet_id": "foo-id"},
-        {"subnet_id": "foo-id", "atomic_action": False},
-        {"pool_create_args": None, "subnet_id": "foo-id",
-         "atomic_action": False},
-        {"pool_create_args": {}, "subnet_id": "foo-id",
-         "atomic_action": False},
-        {"pool_create_args": {"name": "given-name"},
-         "subnet_id": "foo-id", "atomic_action": False},
+        {"subnet_id": "foo-id"}
     )
     @ddt.unpack
-    def test__create_lb_pool(self, subnet_id=None, atomic_action=True,
+    def test__create_lb_pool(self, subnet_id=None,
                              pool_create_args=None):
         pool = {"pool": {"id": "pool-id"}}
         pool_create_args = pool_create_args or {}
@@ -759,14 +941,13 @@ class NeutronScenarioTestCase(test.ScenarioTestCase):
         args.update(pool_create_args)
         expected_pool_data = {"pool": args}
         resultant_pool = self.scenario._create_lb_pool(
-            subnet_id=subnet_id, atomic_action=atomic_action,
+            subnet_id=subnet_id,
             **pool_create_args)
-        self.assertEqual(resultant_pool, pool)
+        self.assertEqual(pool, resultant_pool)
         self.clients("neutron").create_pool.assert_called_once_with(
             expected_pool_data)
-        if atomic_action:
-            self._test_atomic_action_timer(
-                self.scenario.atomic_actions(), "neutron.create_pool")
+        self._test_atomic_action_timer(
+            self.scenario.atomic_actions(), "neutron.create_pool")
 
     @ddt.data(
         {},
@@ -788,7 +969,7 @@ class NeutronScenarioTestCase(test.ScenarioTestCase):
         args.update(vip_create_args)
         expected_vip_data = {"vip": args}
         resultant_vip = self.scenario._create_v1_vip(pool, **vip_create_args)
-        self.assertEqual(resultant_vip, vip)
+        self.assertEqual(vip, resultant_vip)
         self.clients("neutron").create_vip.assert_called_once_with(
             expected_vip_data)
 
@@ -806,12 +987,40 @@ class NeutronScenarioTestCase(test.ScenarioTestCase):
         self.clients("neutron").create_floatingip.return_value = fip
         mock_get_network_id = self.scenario._get_network_id = mock.Mock()
         mock_get_network_id.return_value = network_id
-        args = {"floating_network_id": network_id}
+        args = {"floating_network_id": network_id,
+                "description": "random_name"}
         args.update(floating_ip_args)
         expected_fip_data = {"floatingip": args}
         resultant_fip = self.scenario._create_floatingip(
             floating_network, **floating_ip_args)
-        self.assertEqual(resultant_fip, fip)
+        self.assertEqual(fip, resultant_fip)
+        self.clients("neutron").create_floatingip.assert_called_once_with(
+            expected_fip_data)
+        mock_get_network_id.assert_called_once_with(floating_network)
+        self._test_atomic_action_timer(self.scenario.atomic_actions(),
+                                       "neutron.create_floating_ip")
+
+    @mock.patch("%s.LOG.info" % NEUTRON_UTILS)
+    def test__create_floating_ip_in_pre_newton_openstack(self, mock_log_info):
+        floating_network = "floating"
+        fip = {"floatingip": {"id": "fip-id"}}
+        network_id = "net-id"
+        self.clients("neutron").create_floatingip.return_value = fip
+        mock_get_network_id = self.scenario._get_network_id = mock.Mock()
+        mock_get_network_id.return_value = network_id
+
+        from neutronclient.common import exceptions as n_exceptions
+        e = n_exceptions.BadRequest("Unrecognized attribute(s) 'description'")
+        self.clients("neutron").create_floatingip.side_effect = e
+
+        a_e = self.assertRaises(n_exceptions.BadRequest,
+                                self.scenario._create_floatingip,
+                                floating_network)
+        self.assertEqual(e, a_e)
+        self.assertTrue(mock_log_info.called)
+
+        expected_fip_data = {"floatingip": {"floating_network_id": network_id,
+                                            "description": "random_name"}}
         self.clients("neutron").create_floatingip.assert_called_once_with(
             expected_fip_data)
         mock_get_network_id.assert_called_once_with(floating_network)
@@ -822,14 +1031,9 @@ class NeutronScenarioTestCase(test.ScenarioTestCase):
         {},
         {"healthmonitor_create_args": {}},
         {"healthmonitor_create_args": {"type": "TCP"}},
-        {"atomic_action": False},
-        {"atomic_action": False,
-         "healthmonitor_create_args": {"type": "TCP"}},
-        {"healthmonitor_create_args": {},
-         "atomic_action": False},
     )
     @ddt.unpack
-    def test__create_v1_healthmonitor(self, atomic_action=True,
+    def test__create_v1_healthmonitor(self,
                                       healthmonitor_create_args=None):
         hm = {"health_monitor": {"id": "hm-id"}}
         healthmonitor_create_args = healthmonitor_create_args or {}
@@ -839,14 +1043,12 @@ class NeutronScenarioTestCase(test.ScenarioTestCase):
         args.update(healthmonitor_create_args)
         expected_hm_data = {"health_monitor": args}
         resultant_hm = self.scenario._create_v1_healthmonitor(
-            atomic_action=atomic_action,
             **healthmonitor_create_args)
-        self.assertEqual(resultant_hm, hm)
+        self.assertEqual(hm, resultant_hm)
         self.clients("neutron").create_health_monitor.assert_called_once_with(
             expected_hm_data)
-        if atomic_action:
-            self._test_atomic_action_timer(self.scenario.atomic_actions(),
-                                           "neutron.create_healthmonitor")
+        self._test_atomic_action_timer(self.scenario.atomic_actions(),
+                                       "neutron.create_healthmonitor")
 
     def test_list_v1_healthmonitors(self):
         hm_list = []
@@ -873,7 +1075,7 @@ class NeutronScenarioTestCase(test.ScenarioTestCase):
         healthmonitor_update_args = {"admin_state_up": False}
         result_hm = self.scenario._update_v1_healthmonitor(
             hm, **healthmonitor_update_args)
-        self.assertEqual(result_hm, expected_hm)
+        self.assertEqual(expected_hm, result_hm)
         mock_update.assert_called_once_with(
             hm["health_monitor"]["id"], expected_hm)
         self._test_atomic_action_timer(self.scenario.atomic_actions(),
@@ -947,10 +1149,153 @@ class NeutronScenarioTestCase(test.ScenarioTestCase):
         self._test_atomic_action_timer(self.scenario.atomic_actions(),
                                        "neutron.list_lbaasv2_loadbalancers")
 
+    def test__create_bgpvpn(self, atomic_action=True):
+        bv = {"bgpvpn": {"id": "bgpvpn-id"}}
+        self.admin_clients("neutron").create_bgpvpn.return_value = bv
+        self.scenario.generate_random_name = mock.Mock(
+            return_value="random_name")
+        expected_bv_data = {"bgpvpn": {"name": "random_name"}}
+        resultant_bv = self.scenario._create_bgpvpn()
+        self.assertEqual(bv, resultant_bv)
+        self.admin_clients("neutron").create_bgpvpn.assert_called_once_with(
+            expected_bv_data)
+        if atomic_action:
+            self._test_atomic_action_timer(self.scenario.atomic_actions(),
+                                           "neutron.create_bgpvpn")
+
+    def test_delete_bgpvpn(self):
+        bgpvpn_create_args = {}
+        bgpvpn = self.scenario._create_bgpvpn(**bgpvpn_create_args)
+        self.scenario._delete_bgpvpn(bgpvpn)
+        self._test_atomic_action_timer(self.scenario.atomic_actions(),
+                                       "neutron.delete_bgpvpn")
+
+    def test__list_bgpvpns(self):
+        bgpvpns_list = []
+        bgpvpns_dict = {"bgpvpns": bgpvpns_list}
+        self.admin_clients("neutron").list_bgpvpns.return_value = bgpvpns_dict
+        return_bgpvpns_list = self.scenario._list_bgpvpns()
+        self.assertEqual(bgpvpns_list, return_bgpvpns_list)
+        self._test_atomic_action_timer(self.scenario.atomic_actions(),
+                                       "neutron.list_bgpvpns")
+
+    @ddt.data(
+        {},
+        {"bgpvpn_update_args": {"update_name": True}},
+        {"bgpvpn_update_args": {"update_name": False}},
+    )
+    @ddt.unpack
+    def test__update_bgpvpn(self, bgpvpn_update_args=None):
+        expected_bgpvpn = {"bgpvpn": {}}
+        bgpvpn_update_data = bgpvpn_update_args or {}
+        if bgpvpn_update_data.get("update_name"):
+            expected_bgpvpn = {"bgpvpn": {"name": "updated_name"}}
+        self.admin_clients(
+            "neutron").update_bgpvpn.return_value = expected_bgpvpn
+        self.scenario.generate_random_name = mock.Mock(
+            return_value="updated_name")
+        bgpvpn = {"bgpvpn": {"name": "bgpvpn-name", "id": "bgpvpn-id"}}
+        result_bgpvpn = self.scenario._update_bgpvpn(bgpvpn,
+                                                     **bgpvpn_update_data)
+        self.admin_clients("neutron").update_bgpvpn.assert_called_once_with(
+            bgpvpn["bgpvpn"]["id"], expected_bgpvpn)
+        self.assertEqual(expected_bgpvpn, result_bgpvpn)
+        self._test_atomic_action_timer(self.scenario.atomic_actions(),
+                                       "neutron.update_bgpvpn")
+
+    def test__create_bgpvpn_network_assoc(self):
+        network_id = "network_id"
+        bgpvpn_id = "bgpvpn_id"
+        value = {"network_association": {
+            "network_id": network_id,
+            "id": bgpvpn_id}}
+        self.clients(
+            "neutron").create_bgpvpn_network_assoc.return_value = value
+        network = {"id": network_id}
+        bgpvpn = {"bgpvpn": {"id": bgpvpn_id}}
+        return_value = self.scenario._create_bgpvpn_network_assoc(bgpvpn,
+                                                                  network)
+        netassoc = {"network_id": network["id"]}
+        self.clients(
+            "neutron").create_bgpvpn_network_assoc.assert_called_once_with(
+            bgpvpn_id, {"network_association": netassoc})
+        self.assertEqual(return_value, value)
+        self._test_atomic_action_timer(self.scenario.atomic_actions(),
+                                       "neutron.create_bgpvpn_network_assoc")
+
+    def test__create_router_network_assoc(self):
+        router_id = "router_id"
+        bgpvpn_id = "bgpvpn_id"
+        value = {"router_association": {
+            "router_id": router_id,
+            "id": "asso_id"}}
+        self.clients("neutron").create_bgpvpn_router_assoc.return_value = value
+        router = {"id": router_id}
+        bgpvpn = {"bgpvpn": {"id": bgpvpn_id}}
+        return_value = self.scenario._create_bgpvpn_router_assoc(bgpvpn,
+                                                                 router)
+        router_assoc = {"router_id": router["id"]}
+        self.clients(
+            "neutron").create_bgpvpn_router_assoc.assert_called_once_with(
+            bgpvpn_id, {"router_association": router_assoc})
+        self.assertEqual(return_value, value)
+        self._test_atomic_action_timer(self.scenario.atomic_actions(),
+                                       "neutron.create_bgpvpn_router_assoc")
+
+    def test__delete_bgpvpn_network_assoc(self):
+        bgpvpn_assoc_args = {}
+        asso_id = "aaaa-bbbb"
+        network_assoc = {"network_association": {"id": asso_id}}
+        bgpvpn = self.scenario._create_bgpvpn(**bgpvpn_assoc_args)
+        self.scenario._delete_bgpvpn_network_assoc(bgpvpn, network_assoc)
+        self.clients(
+            "neutron").delete_bgpvpn_network_assoc.assert_called_once_with(
+            bgpvpn["bgpvpn"]["id"], asso_id)
+        self._test_atomic_action_timer(self.scenario.atomic_actions(),
+                                       "neutron.delete_bgpvpn_network_assoc")
+
+    def test__delete_bgpvpn_router_assoc(self):
+        bgpvpn_assoc_args = {}
+        asso_id = "aaaa-bbbb"
+        router_assoc = {"router_association": {"id": asso_id}}
+        bgpvpn = self.scenario._create_bgpvpn(**bgpvpn_assoc_args)
+        self.scenario._delete_bgpvpn_router_assoc(bgpvpn, router_assoc)
+        self.clients(
+            "neutron").delete_bgpvpn_router_assoc.assert_called_once_with(
+            bgpvpn["bgpvpn"]["id"], asso_id)
+        self._test_atomic_action_timer(self.scenario.atomic_actions(),
+                                       "neutron.delete_bgpvpn_router_assoc")
+
+    def test__list_bgpvpn_network_assocs(self):
+        value = {"network_associations": []}
+        bgpvpn_id = "bgpvpn-id"
+        bgpvpn = {"bgpvpn": {"id": bgpvpn_id}}
+        self.clients("neutron").list_bgpvpn_network_assocs.return_value = value
+        return_asso_list = self.scenario._list_bgpvpn_network_assocs(bgpvpn)
+        self.clients(
+            "neutron").list_bgpvpn_network_assocs.assert_called_once_with(
+            bgpvpn_id)
+        self.assertEqual(value, return_asso_list)
+        self._test_atomic_action_timer(self.scenario.atomic_actions(),
+                                       "neutron.list_bgpvpn_network_assocs")
+
+    def test__list_bgpvpn_router_assocs(self):
+        value = {"router_associations": []}
+        bgpvpn_id = "bgpvpn-id"
+        bgpvpn = {"bgpvpn": {"id": bgpvpn_id}}
+        self.clients("neutron").list_bgpvpn_router_assocs.return_value = value
+        return_asso_list = self.scenario._list_bgpvpn_router_assocs(bgpvpn)
+        self.clients(
+            "neutron").list_bgpvpn_router_assocs.assert_called_once_with(
+            bgpvpn_id)
+        self.assertEqual(value, return_asso_list)
+        self._test_atomic_action_timer(self.scenario.atomic_actions(),
+                                       "neutron.list_bgpvpn_router_assocs")
+
 
 class NeutronScenarioFunctionalTestCase(test.FakeClientsScenarioTestCase):
 
-    @mock.patch(NEUTRON_UTILS + "network_wrapper.generate_cidr")
+    @mock.patch("%s.network_wrapper.generate_cidr" % NEUTRON_UTILS)
     def test_functional_create_network_and_subnets(self, mock_generate_cidr):
         scenario = utils.NeutronScenario(context=self.context)
         network_create_args = {}
