@@ -13,8 +13,8 @@
 #    under the License.
 
 import mock
-from oslo_config import cfg
 
+from rally.common import cfg
 from rally.plugins.openstack.services.storage import cinder_v2
 from tests.unit import fakes
 from tests.unit import test
@@ -231,7 +231,7 @@ class CinderV2ServiceTestCase(test.ScenarioTestCase):
 
         result = self.service.update_volume_type(volume_type,
                                                  description=description,
-                                                 update_name=True,
+                                                 name=None,
                                                  is_public=None)
         self.assertEqual(
             self.cinder.volume_types.update.return_value,
