@@ -15,8 +15,8 @@
 
 import ddt
 import mock
-from oslo_config import cfg
 
+from rally.common import cfg
 from rally.plugins.openstack import osclients
 from rally.plugins.openstack.verification.tempest import config
 from tests.unit import fakes
