@@ -19,11 +19,10 @@ import copy
 import os
 
 import ddt
-import jsonschema
 import mock
-from oslo_config import cfg
 
 from rally import api
+from rally.common import cfg
 from rally.common import objects
 from rally import consts
 from rally import exceptions
@@ -33,8 +32,7 @@ from tests.unit import test
 
 FAKE_DEPLOYMENT_CONFIG = {
     # TODO(akscram): A fake engine is more suitable for that.
-    "type": "ExistingCloud",
-    "creds": {"openstack": {
+    "openstack": {
         "auth_url": "http://example.net:5000/v2.0/",
         "admin": {
             "username": "admin",
@@ -43,10 +41,12 @@ FAKE_DEPLOYMENT_CONFIG = {
             "domain_name": None,
             "project_domain_name": "Default",
             "user_domain_name": "Default",
-            "profiler_hmac_key": None
+            "profiler_hmac_key": None,
+            "profiler_conn_str": None
         },
         "region_name": "RegionOne",
-        "endpoint_type": consts.EndpointType.INTERNAL}}
+        "endpoint_type": consts.EndpointType.INTERNAL
+    }
 }
 
 
@@ -73,24 +73,24 @@ class TaskAPITestCase(test.TestCase):
     @mock.patch("rally.api.engine.TaskEngine")
     def test_validate(self, mock_task_engine, mock_deployment_get, mock_task,
                       mock_task_config):
-        fake_deployment = fakes.FakeDeployment(
-            uuid="deployment_uuid_1", admin="fake_admin", users=["fake_user"])
+        fake_deployment = mock.Mock()
+        fake_env = fake_deployment.env_obj
         mock_deployment_get.return_value = fake_deployment
 
         #######################################################################
         # The case #1 -- create temporary task
         #######################################################################
-        self.task_inst.validate(deployment=fake_deployment["uuid"],
+        self.task_inst.validate(deployment=fake_deployment.uuid,
                                 config="config")
 
         mock_task_engine.assert_called_once_with(
             mock_task_config.return_value, mock_task.return_value,
-            fake_deployment),
+            fake_env),
         mock_task_engine.return_value.validate.assert_called_once_with()
 
         mock_task.assert_called_once_with(
-            temporary=True, deployment_uuid=fake_deployment["uuid"])
-        mock_deployment_get.assert_called_once_with(fake_deployment["uuid"])
+            temporary=True, env_uuid=fake_deployment.uuid)
+        mock_deployment_get.assert_called_once_with(fake_deployment.uuid)
         self.assertFalse(mock_task.get.called)
 
         #######################################################################
@@ -105,12 +105,12 @@ class TaskAPITestCase(test.TestCase):
 
         task_uuid = "task-id"
 
-        self.task_inst.validate(deployment=fake_deployment["uuid"],
+        self.task_inst.validate(deployment=fake_deployment.uuid,
                                 config="config",
                                 task=task_uuid)
 
         mock_task_engine.assert_called_once_with(
-            mock_task_config.return_value, fake_task, fake_deployment)
+            mock_task_config.return_value, fake_task, fake_env)
         mock_task_engine.return_value.validate.assert_called_once_with()
 
         self.assertFalse(mock_task.called)
@@ -129,12 +129,12 @@ class TaskAPITestCase(test.TestCase):
 
         task_instance = fakes.FakeTask(uuid="task-id")
 
-        self.task_inst.validate(deployment=fake_deployment["uuid"],
+        self.task_inst.validate(deployment=fake_deployment.uuid,
                                 config="config",
                                 task_instance=task_instance)
 
         mock_task_engine.assert_called_once_with(
-            mock_task_config.return_value, fake_task, fake_deployment)
+            mock_task_config.return_value, fake_task, fake_env)
         mock_task_engine.return_value.validate.assert_called_once_with()
 
         self.assertFalse(mock_task.called)
@@ -151,7 +151,7 @@ class TaskAPITestCase(test.TestCase):
 
         e = self.assertRaises(exceptions.InvalidTaskException,
                               self.task_inst.validate,
-                              deployment=fake_deployment["uuid"],
+                              deployment=fake_deployment.uuid,
                               config="config",
                               task_instance=task_instance)
         self.assertIn("Who is a good boy?! Woof.", "%s" % e)
@@ -247,7 +247,7 @@ class TaskAPITestCase(test.TestCase):
         self.task_inst.create(
             deployment=mock_deployment_get.return_value["uuid"], tags=tags)
         mock_task.assert_called_once_with(
-            deployment_uuid=mock_deployment_get.return_value["uuid"],
+            env_uuid=mock_deployment_get.return_value["uuid"],
             tags=tags)
 
     @mock.patch("rally.common.objects.Deployment.get",
@@ -270,9 +270,10 @@ class TaskAPITestCase(test.TestCase):
         fake_task = fakes.FakeTask(uuid="some_uuid")
         fake_task.get_status = mock.Mock()
         mock_task.return_value = fake_task
-        mock_deployment_get.return_value = fakes.FakeDeployment(
+        fake_deployment = fakes.FakeDeployment(
             uuid="deployment_uuid", admin="fake_admin", users=["fake_user"],
             status=consts.DeployStatus.DEPLOY_FINISHED)
+        mock_deployment_get.return_value = fake_deployment
         task_config_instance = mock_task_config.return_value
 
         self.assertEqual(
@@ -285,7 +286,7 @@ class TaskAPITestCase(test.TestCase):
         mock_task_engine.assert_called_once_with(
             task_config_instance,
             mock_task.return_value,
-            mock_deployment_get.return_value,
+            fake_deployment.env_obj,
             abort_on_sla_failure=False
         )
         task_engine = mock_task_engine.return_value
@@ -325,7 +326,7 @@ class TaskAPITestCase(test.TestCase):
             status=consts.DeployStatus.DEPLOY_INCONSISTENT,
             name="foo")
         mock_deployment_get.return_value = fake_deployment
-        fake_task_dict = {"deployment_uuid": deployment_uuid,
+        fake_task_dict = {"env_uuid": deployment_uuid,
                           "uuid": "some_uuid"}
         fake_task = objects.Task(task=fake_task_dict)
         mock_task_get.return_value = fake_task
@@ -343,16 +344,13 @@ class TaskAPITestCase(test.TestCase):
     @mock.patch("rally.api.CONF", spec=cfg.CONF)
     def test_start_exception(self, mock_conf, mock_task_engine,
                              mock_deployment_get, mock_task, mock_task_config):
-        fake_deployment = fakes.FakeDeployment(
+        mock_deployment_get.return_value = fakes.FakeDeployment(
             status=consts.DeployStatus.DEPLOY_FINISHED,
             name="foo", uuid="deployment_uuid")
-        mock_deployment_get.return_value = fake_deployment
         mock_task.return_value.is_temporary = False
         mock_task_engine.return_value.run.side_effect = TypeError
         self.assertRaises(TypeError, self.task_inst.start,
                           deployment="deployment_uuid", config="config")
-        fake_deployment.update_status.assert_called_once_with(
-            consts.DeployStatus.DEPLOY_INCONSISTENT)
 
     @mock.patch("rally.api.objects.Task")
     @mock.patch("rally.api.objects.Deployment.get")
@@ -455,8 +453,10 @@ class TaskAPITestCase(test.TestCase):
     @mock.patch("rally.api.texporter.TaskExporter")
     @mock.patch("rally.api.objects.Task.get")
     def test_export(self, mock_task_get, mock_task_exporter):
-        task_id = ["uuid-1", "uuid-2"]
+        tasks_id = ["uuid-1", "uuid-2"]
         tasks = [mock.Mock(), mock.Mock()]
+        tasks[0].to_dict.return_value = {"uuid": "uuid-1"}
+        tasks[1].to_dict.return_value = {"uuid": "uuid-2"}
         mock_task_get.side_effect = tasks
         output_type = mock.Mock()
         output_dest = mock.Mock()
@@ -466,7 +466,7 @@ class TaskAPITestCase(test.TestCase):
 
         self.assertEqual(mock_task_exporter.make.return_value,
                          self.task_inst.export(
-                             tasks_uuids=task_id,
+                             tasks=tasks_id + [{"uuid": "uuid-3"}],
                              output_type=output_type,
                              output_dest=output_dest))
         mock_task_exporter.get.assert_called_once_with(output_type)
@@ -477,9 +477,10 @@ class TaskAPITestCase(test.TestCase):
             vtype="syntax")
 
         mock_task_exporter.make.assert_called_once_with(
-            reporter, [t.to_dict.return_value for t in tasks],
+            reporter,
+            [t.to_dict.return_value for t in tasks] + [{"uuid": "uuid-3"}],
             output_dest, api=self.task_inst.api)
-        self.assertEqual([mock.call(u, detailed=True) for u in task_id],
+        self.assertEqual([mock.call(u, detailed=True) for u in tasks_id],
                          mock_task_get.call_args_list)
 
     @mock.patch("rally.api.objects.Task")
@@ -516,7 +517,8 @@ class TaskAPITestCase(test.TestCase):
                     "position": 77,
                     "runner": {},
                     "runner_type": "",
-                    "context": {},
+                    "contexts": {},
+                    "contexts_results": [],
                     "hooks": [],
                     "pass_sla": True,
                     "sla": {},
@@ -538,7 +540,7 @@ class TaskAPITestCase(test.TestCase):
                 task_results=task_results)
         )
 
-        mock_task.assert_called_once_with(deployment_uuid="deployment_uuid",
+        mock_task.assert_called_once_with(env_uuid="deployment_uuid",
                                           tags=None)
         mock_task.return_value.update_status.assert_has_calls(
             [mock.call(consts.TaskStatus.RUNNING),
@@ -548,10 +550,12 @@ class TaskAPITestCase(test.TestCase):
             title="subtask-title")
         sub_task = mock_task.return_value.add_subtask.return_value
         sub_task.add_workload.assert_called_once_with(
-            name=workload["name"], description=workload["description"],
+            name=workload["name"],
+            description=workload["description"],
             position=workload["position"], runner=workload["runner"],
             runner_type=workload["runner_type"],
-            context=workload["context"], sla=workload["sla"],
+            contexts=workload["contexts"],
+            sla=workload["sla"],
             hooks=workload["hooks"], args=workload["args"]
         )
         sub_task.update_status.assert_called_once_with(
@@ -563,6 +567,7 @@ class TaskAPITestCase(test.TestCase):
             full_duration=workload["full_duration"],
             load_duration=workload["load_duration"],
             sla_results=workload["sla_results"]["sla"],
+            contexts_results=workload["contexts_results"],
             hooks_results=workload["hooks"], start_time=workload["start_time"])
 
     @mock.patch("rally.api.objects.Task")
@@ -583,7 +588,8 @@ class TaskAPITestCase(test.TestCase):
                     "position": 77,
                     "runner": {},
                     "runner_type": "",
-                    "context": {},
+                    "contexts": {"foo": {"killall": False}},
+                    "contexts_results": [],
                     "hooks": [],
                     "pass_sla": True,
                     "sla": {},
@@ -606,7 +612,7 @@ class TaskAPITestCase(test.TestCase):
                 task_results=task_results)
         )
 
-        mock_task.assert_called_once_with(deployment_uuid="deployment_uuid",
+        mock_task.assert_called_once_with(env_uuid="deployment_uuid",
                                           tags=None)
         mock_task.return_value.update_status.assert_has_calls(
             [mock.call(consts.TaskStatus.RUNNING),
@@ -616,11 +622,15 @@ class TaskAPITestCase(test.TestCase):
             title=task_results["subtasks"][0]["title"])
         sub_task = mock_task.return_value.add_subtask.return_value
         sub_task.add_workload.assert_called_once_with(
-            name=workload["name"], description=workload["description"],
-            position=workload["position"], runner=workload["runner"],
+            name=workload["name"],
+            description=workload["description"],
+            position=workload["position"],
+            runner=workload["runner"],
             runner_type=workload["runner_type"],
-            context=workload["context"], sla=workload["sla"],
-            hooks=workload["hooks"], args=workload["args"]
+            contexts=workload["contexts"],
+            sla=workload["sla"],
+            hooks=workload["hooks"],
+            args=workload["args"]
         )
         sub_task.update_status.assert_called_once_with(
             consts.SubtaskStatus.FINISHED)
@@ -633,12 +643,12 @@ class TaskAPITestCase(test.TestCase):
             full_duration=workload["full_duration"],
             load_duration=workload["load_duration"],
             sla_results=workload["sla_results"]["sla"],
+            contexts_results=workload["contexts_results"],
             hooks_results=workload["hooks"], start_time=workload["start_time"])
 
     @mock.patch("rally.api.objects.Deployment.get")
-    @mock.patch("rally.api.jsonschema.validate", return_value=True)
     def test_import_results_with_inconsistent_deployment(
-            self, mock_jsonschema_validate, mock_deployment_get):
+            self, mock_deployment_get):
         fake_deployment = fakes.FakeDeployment(
             uuid="deployment_uuid", admin="fake_admin", users=["fake_user"],
             status=consts.DeployStatus.DEPLOY_INCONSISTENT,
@@ -653,9 +663,8 @@ class TaskAPITestCase(test.TestCase):
 
     @mock.patch("rally.api.objects.Task")
     @mock.patch("rally.api.objects.Deployment.get")
-    @mock.patch("rally.api.jsonschema.validate", return_value=True)
     def test_import_results_with_error_data(
-            self, mock_jsonschema_validate, mock_deployment_get, mock_task):
+            self, mock_deployment_get, mock_task):
         mock_deployment_get.return_value = fakes.FakeDeployment(
             uuid="deployment_uuid", admin="fake_admin", users=["fake_user"],
             status=consts.DeployStatus.DEPLOY_FINISHED)
@@ -680,8 +689,7 @@ class BaseDeploymentTestCase(test.TestCase):
         self.deployment_inst = api._Deployment(mock_api)
         self.deployment_config = copy.deepcopy(FAKE_DEPLOYMENT_CONFIG)
         self.deployment_uuid = "599bdf1d-fe77-461a-a810-d59b1490f4e3"
-        creds = copy.deepcopy(FAKE_DEPLOYMENT_CONFIG)["creds"]
-        admin_credential = creds["openstack"]
+        admin_credential = copy.deepcopy(self.deployment_config["openstack"])
         admin_credential["endpoint"] = None
         admin_credential.update(admin_credential.pop("admin"))
         admin_credential["permission"] = consts.EndpointPermission.ADMIN
@@ -697,59 +705,59 @@ class BaseDeploymentTestCase(test.TestCase):
 
 
 class DeploymentAPITestCase(BaseDeploymentTestCase):
-    @mock.patch("rally.common.objects.deploy.db.deployment_update")
-    @mock.patch("rally.common.objects.deploy.db.deployment_create")
-    @mock.patch("rally.deployment.engines.existing.ExistingCloud.validate")
-    def test_create(self, mock_existing_cloud_validate,
-                    mock_deployment_create, mock_deployment_update):
-        mock_deployment_create.return_value = self.deployment
-        mock_deployment_update.return_value = self.deployment
+    @mock.patch("rally.api.objects.Deployment")
+    def test_create(self, mock_deployment):
         dep = self.deployment_inst.create(config=self.deployment_config,
                                           name="fake_deployment")
-        self.assertIsInstance(dep, dict)
-        mock_deployment_create.assert_called_once_with({
-            "name": "fake_deployment",
-            "config": self.deployment_config,
-        })
-        mock_existing_cloud_validate.assert_called_once_with()
-        mock_deployment_update.assert_has_calls([
-            mock.call(self.deployment_uuid,
-                      {"credentials": {"openstack": [self.credentials]}})
-        ])
+        self.assertEqual(mock_deployment.return_value.to_dict.return_value,
+                         dep)
+        mock_deployment.assert_called_once_with(
+            name="fake_deployment",
+            config=self.deployment_config,
+            extras={})
 
-    @mock.patch("rally.common.objects.deploy.db.deployment_update")
-    @mock.patch("rally.common.objects.deploy.db.deployment_create")
-    @mock.patch("rally.deployment.engines.existing.ExistingCloud.validate",
-                side_effect=jsonschema.ValidationError("ValidationError"))
-    def test_create_validation_error(
-            self, mock_existing_cloud_validate, mock_deployment_create,
-            mock_deployment_update):
-        mock_deployment_create.return_value = self.deployment
-        self.assertRaises(jsonschema.ValidationError,
-                          self.deployment_inst.create,
-                          config=self.deployment_config,
-                          name="fake_deployment")
-        mock_deployment_update.assert_called_once_with(
-            self.deployment_uuid,
-            {"status": consts.DeployStatus.DEPLOY_FAILED})
+    @mock.patch("rally.api.objects.Deployment")
+    def test_create_duplicate(self, mock_deployment):
 
-    @mock.patch("rally.api.LOG")
-    @mock.patch("rally.common.objects.deploy.db.deployment_create",
-                side_effect=exceptions.DeploymentNameExists(
-                    deployment="fake_deploy"))
-    def test_create_duplication_error(self, mock_deployment_create, mock_log):
-        self.assertRaises(exceptions.DeploymentNameExists,
-                          self.deployment_inst.create,
-                          config=self.deployment_config,
-                          name="fake_deployment")
+        exc = exceptions.DBRecordExists(
+            field="name", value="fake_deployment", table="envs")
 
-    @mock.patch("rally.common.objects.deploy.db.deployment_delete")
-    @mock.patch("rally.common.objects.deploy.db.deployment_update")
-    @mock.patch("rally.common.objects.deploy.db.deployment_get")
-    def test_destroy(self, mock_deployment_get, mock_deployment_update,
-                     mock_deployment_delete):
-        mock_deployment_get.return_value = self.deployment
-        mock_deployment_update.return_value = self.deployment
+        mock_deployment.side_effect = exc
+
+        a_exc = self.assertRaises(
+            exceptions.DBRecordExists,
+            self.deployment_inst.create, config=self.deployment_config,
+            name="fake_deployment")
+        self.assertEqual(exc, a_exc)
+
+    @mock.patch("rally.api.objects.Deployment")
+    def test_create_with_old_cfg(self, mock_deployment):
+        mock_deployment.return_value.spec = ""
+
+        config = {"type": "ExistingCloud",
+                  "creds": self.deployment_config}
+
+        dep = self.deployment_inst.create(config=config,
+                                          name="fake_deployment")
+        self.assertEqual(mock_deployment.return_value.to_dict.return_value,
+                         dep)
+        mock_deployment.assert_called_once_with(
+            name="fake_deployment",
+            config=self.deployment_config,
+            extras={})
+
+        config = {"type": "Something",
+                  "creds": self.deployment_config}
+
+        e = self.assertRaises(
+            exceptions.RallyException,
+            self.deployment_inst.create, config=config,
+            name="fake_deployment")
+        self.assertIn("You are using deployment type which doesn't exist.",
+                      "%s" % e)
+
+    @mock.patch("rally.common.objects.deploy.env_mgr.EnvManager.get")
+    def test_destroy(self, mock_env_manager_get):
 
         list_verifiers = [{"name": "f1", "uuid": "1"},
                           {"name": "f2", "uuid": "2"}]
@@ -757,133 +765,35 @@ class DeploymentAPITestCase(BaseDeploymentTestCase):
 
         self.deployment_inst.destroy(deployment=self.deployment_uuid)
 
-        mock_deployment_get.assert_called_once_with(self.deployment_uuid)
-        mock_deployment_delete.assert_called_once_with(self.deployment_uuid)
-        self.deployment_inst.api.verifier.list.assert_called_once_with()
-        self.assertEqual(
-            [mock.call(verifier_id=m["name"],
-                       deployment_id=self.deployment["name"],
-                       force=True)
-             for m in list_verifiers],
-            self.deployment_inst.api.verifier.delete.call_args_list)
+        mock_env_manager_get.assert_called_once_with(self.deployment_uuid)
+        mock_env_manager_get.return_value.destroy.assert_called_once_with(
+            skip_cleanup=True
+        )
 
-    @mock.patch("rally.common.objects.deploy.db.deployment_update")
-    @mock.patch("rally.common.objects.deploy.db.deployment_get")
-    def test_recreate(self, mock_deployment_get, mock_deployment_update):
-        mock_deployment_get.return_value = self.deployment
-        mock_deployment_update.return_value = self.deployment
-        self.deployment_inst.recreate(deployment=self.deployment_uuid)
-        mock_deployment_get.assert_called_once_with(self.deployment_uuid)
-        mock_deployment_update.assert_has_calls([
-            mock.call(
-                self.deployment_uuid,
-                {"credentials":
-                    {"openstack": [{"admin": self.credentials["admin"],
-                                    "users": self.credentials["users"]}]}})
-        ])
+    def test_recreate(self):
+        e = self.assertRaises(exceptions.RallyException,
+                              self.deployment_inst.recreate, deployment="")
+        self.assertIn("Sorry, but recreate method", "%s" % e)
 
-    @mock.patch("rally.common.objects.deploy.db.deployment_update")
-    @mock.patch("rally.common.objects.deploy.db.deployment_get")
-    def test_recreate_config(self, mock_deployment_get,
-                             mock_deployment_update):
-        mock_deployment_get.return_value = self.deployment
-        mock_deployment_update.return_value = self.deployment
-        config = copy.deepcopy(self.deployment_config)
-        config["creds"]["openstack"]["admin"] = {
-            "username": "admin",
-            "password": "pass1",
-            "tenant_name": "demo"}
-        config["creds"]["openstack"]["users"] = [
-            {"username": "user1",
-             "password": "pass2",
-             "tenant_name": "demo"}]
-
-        self.deployment_inst.recreate(deployment=self.deployment_uuid,
-                                      config=config)
-        mock_deployment_get.assert_called_once_with(self.deployment_uuid)
-        mock_deployment_update.assert_has_calls([
-            mock.call(self.deployment_uuid, {"config": config}),
-        ])
-
-    @mock.patch("rally.common.objects.deploy.db.deployment_update")
-    @mock.patch("rally.common.objects.deploy.db.deployment_get")
-    def test_recreate_old_config(self, mock_deployment_get,
-                                 mock_deployment_update):
-        mock_deployment_get.return_value = self.deployment
-        mock_deployment_update.return_value = self.deployment
-        config = copy.deepcopy(self.deployment_config["creds"])
-        config["openstack"]["admin"] = {
-            "username": "admin",
-            "password": "pass1",
-            "tenant_name": "demo"}
-        config["openstack"]["users"] = [
-            {"username": "user1",
-             "password": "pass2",
-             "tenant_name": "demo"}]
-
-        self.deployment_inst.recreate(deployment=self.deployment_uuid,
-                                      config=config)
-        mock_deployment_get.assert_called_once_with(self.deployment_uuid)
-        mock_deployment_update.assert_has_calls([
-            mock.call(self.deployment_uuid,
-                      {"config": {"type": "ExistingCloud", "creds": config}}),
-        ])
-
-    @mock.patch("rally.common.objects.deploy.db.deployment_update")
-    @mock.patch("rally.common.objects.deploy.db.deployment_get")
-    def test_recreate_config_invalid(self, mock_deployment_get,
-                                     mock_deployment_update):
-        mock_deployment_get.return_value = self.deployment
-        mock_deployment_update.return_value = self.deployment
-        config = copy.deepcopy(self.deployment_config)
-        config["admin"] = {"foo": "bar"}
-
-        self.assertRaises(jsonschema.ValidationError,
-                          self.deployment_inst.recreate,
-                          deployment=self.deployment_uuid,
-                          config=config)
-
-    @mock.patch("rally.common.objects.deploy.db.deployment_update")
-    @mock.patch("rally.common.objects.deploy.db.deployment_get")
-    def test_recreate_config_wrong_type(self, mock_deployment_get,
-                                        mock_deployment_update):
-        mock_deployment_get.return_value = self.deployment
-        mock_deployment_update.return_value = self.deployment
-        config = copy.deepcopy(self.deployment_config)
-        config["type"] = "foo"
-
-        self.assertRaises(exceptions.RallyException,
-                          self.deployment_inst.recreate,
-                          deployment=self.deployment_uuid,
-                          config=config)
-
-    @mock.patch("rally.common.objects.deploy.db.deployment_get")
-    def test_get(self, mock_deployment_get):
+    @mock.patch("rally.common.objects.deploy.env_mgr.EnvManager.get")
+    def test_get(self, mock_env_manager_get):
         origin_config = copy.deepcopy(self.deployment_config)
-        deployment_id = "aaaa-bbbb-cccc-dddd"
-        mock_deployment_get.return_value = self.deployment
-        ret = self.deployment_inst.get(deployment=deployment_id)
+        mock_env_manager_get.return_value.data = {
+            "spec": self.deployment_config,
+            "platforms": {},
+            "id": self.id(),
+            "uuid": self.deployment["uuid"],
+            "extras": {},
+            "name": self.deployment["name"],
+            "created_at": mock.Mock(),
+            "updated_at": mock.Mock()}
+        ret = self.deployment_inst.get(deployment=self.deployment["uuid"])
         for key in self.deployment:
             self.assertIn(key, ret)
-            if key != "config":
-                self.assertEqual(self.deployment[key], ret[key])
-        self.assertEqual(origin_config["creds"], ret["config"])
-
-    @mock.patch("rally.common.objects.deploy.db.deployment_get")
-    def test_get_deprecated_formats(self, mock_deployment_get):
-        origin_config = copy.deepcopy(self.deployment_config)
-        self.deployment_config.update(
-            **self.deployment_config.pop("creds")["openstack"])
-        deployment_id = "aaaa-bbbb-cccc-dddd"
-        mock_deployment_get.return_value = self.deployment
-        ret = self.deployment_inst.get(deployment=deployment_id)
-        for key in self.deployment:
-            self.assertIn(key, ret)
-            if key != "config":
-                self.assertEqual(self.deployment[key], ret[key])
-        origin_config.pop("type")
-
-        self.assertEqual(origin_config["creds"], ret["config"])
+            if key not in ("credentials", "config"):
+                self.assertEqual(self.deployment[key], ret[key],
+                                 "The key '%s' differs." % key)
+        self.assertEqual(origin_config, ret["config"])
 
     @mock.patch("rally.common.objects.Deployment.list")
     def test_list(self, mock_deployment_list):
@@ -896,90 +806,83 @@ class DeploymentAPITestCase(BaseDeploymentTestCase):
 
     @mock.patch("rally.common.objects.Deployment.get")
     def test_deployment_check(self, mock_deployment_get):
-        fake_credential1 = fakes.fake_credential()
-        fake_credential2 = fakes.fake_credential()
-
-        mock_deployment_get.return_value.get_all_credentials.return_value = {
-            "openstack": [{"admin": fake_credential1,
-                           "users": [fake_credential2]}]}
+        env = mock_deployment_get.return_value.env_obj
+        env.check_health.return_value = {
+            "foo": {"available": True}
+        }
 
         self.assertEqual(
-            {"openstack": [
-                {"services": fake_credential1.list_services.return_value}]},
+            {"foo": [{"services": []}]},
             self.deployment_inst.check(deployment="uuid"))
-
-        fake_credential1.verify_connection.assert_called_once_with()
-        fake_credential2.verify_connection.assert_called_once_with()
+        env.check_health.assert_called_once_with()
+        self.assertFalse(env.get_info.called)
 
     @mock.patch("rally.common.objects.Deployment.get")
-    def test_deployment_check_list_services_via_admin(self,
-                                                      mock_deployment_get):
-        fake_credential1 = fakes.fake_credential()
-        fake_credential2 = fakes.fake_credential()
-
-        mock_deployment_get.return_value.get_all_credentials.return_value = {
-            "openstack": [{"admin": fake_credential1,
-                           "users": [fake_credential2]}]}
+    def test_deployment_check_list_services(self, mock_deployment_get):
+        env = mock_deployment_get.return_value.env_obj
+        env.get_info.return_value = {
+            "existing@openstack": {"info": {
+                "services": [{"type": "foo", "name": "bar"},
+                             {"type": "volumev4"}]}}
+        }
+        env.check_health.return_value = {
+            "existing@openstack": {"available": True}
+        }
 
         self.assertEqual(
-            {"openstack": [
-                {"services": fake_credential1.list_services.return_value}]},
+            {"openstack": [{
+                "services": [{"type": "foo", "name": "bar"},
+                             {"type": "volumev4", "name": "__unknown__"}]}]},
             self.deployment_inst.check(deployment="uuid"))
-
-        fake_credential1.verify_connection.assert_called_once_with()
-        fake_credential1.list_services.assert_called_once_with()
-        fake_credential2.verify_connection.assert_called_once_with()
-        self.assertFalse(fake_credential2.list_services.called)
+        env.check_health.assert_called_once_with()
+        env.get_info.assert_called_once_with()
 
     @mock.patch("rally.common.objects.Deployment.get")
-    def test_deployment_check_list_services_via_user(self,
-                                                     mock_deployment_get):
-        fake_credential1 = fakes.fake_credential()
-        fake_credential2 = fakes.fake_credential()
+    def test_deployment_check_fails(self, mock_deployment_get):
+        env = mock_deployment_get.return_value.env_obj
+        env.get_info.return_value = {
+            "existing@openstack": {"info": {"services": [{"foo": "bar"}]}}
+        }
 
-        mock_deployment_get.return_value.get_all_credentials.return_value = {
-            "openstack": [{"admin": None,
-                           "users": [fake_credential2, fake_credential1]}]}
+        trace1 = ("Traceback (most recent call last):\n"
+                  "  File '<ipython-input-3-e551aac575a4>', line 2, in "
+                  "<module>\n"
+                  "    raise Exception('asd: asd :asd asd ')\n"
+                  "Exception: asd: asd :asd asd \n")
+        msg1 = "Bad user creds: oops"
+        trace2 = ("Traceback (most recent call last):\n"
+                  "  File '<ipython-input-3-e551aac575a4>', line 2, in "
+                  "<module>\n"
+                  "    raise KeyError('asd: asd :asd asd2 ')\n"
+                  "KeyError: asd: asd :asd asd2 \n")
+        msg2 = "Ooops"
+        env.check_health.return_value = {
+            "existing@openstack": {
+                "available": False,
+                "message": msg1,
+                "traceback": trace1},
+            "foo@bar": {
+                "available": False,
+                "message": msg2,
+                "traceback": trace2
+            }
+        }
 
         self.assertEqual(
-            {"openstack": [
-                {"services": fake_credential2.list_services.return_value}]},
+            {
+                "openstack": [{
+                    "services": [],
+                    "user_error": {"etype": "Exception",
+                                   "msg": msg1,
+                                   "trace": trace1}}],
+                "foo@bar": [{
+                    "services": [],
+                    "admin_error": {"etype": "KeyError",
+                                    "msg": msg2,
+                                    "trace": trace2}}]},
             self.deployment_inst.check(deployment="uuid"))
-
-        fake_credential2.verify_connection.assert_called_once_with()
-        fake_credential2.list_services.assert_called_once_with()
-        fake_credential1.verify_connection.assert_called_once_with()
-        self.assertFalse(fake_credential1.list_services.called)
-
-    @mock.patch("rally.api.traceback")
-    @mock.patch("rally.common.objects.Deployment.get")
-    def test_deployment_check_fails(self, mock_deployment_get, mock_traceback):
-        mock_traceback.format_exc.side_effect = ("Trace1", "Trace2")
-        fake_credential1 = fakes.fake_credential()
-        fake_credential2 = fakes.fake_credential()
-
-        fake_credential1.verify_connection.side_effect = KeyError("oops")
-        fake_credential2.verify_connection.side_effect = TypeError("ooooops")
-
-        mock_deployment_get.return_value.get_all_credentials.return_value = {
-            "openstack": [{"admin": fake_credential1,
-                           "users": [fake_credential2]}]}
-
-        self.assertEqual(
-            {"openstack": [
-                {"services": [],
-                 "admin_error": {
-                     "etype": "KeyError", "msg": "'oops'",
-                     "trace": "Trace1"},
-                 "user_error": {
-                     "etype": "TypeError", "msg": "ooooops",
-                     "trace": "Trace2"}}]},
-            self.deployment_inst.check(deployment="uuid"))
-
-        fake_credential1.verify_connection.assert_called_once_with()
-        fake_credential2.verify_connection.assert_called_once_with()
-        self.assertFalse(fake_credential1.list_services.called)
-        self.assertFalse(fake_credential2.list_services.called)
+        env.check_health.assert_called_once_with()
+        self.assertFalse(env.get_info.called)
 
     def test_service_list(self):
         fake_credential = fakes.fake_credential()
@@ -1198,7 +1101,8 @@ class VerifierAPITestCase(test.TestCase):
     @mock.patch("rally.api.vmanager.VerifierManager.get")
     def test_create(self, mock_verifier_manager_get, mock___verifier__get,
                     mock_verifier_create):
-        mock___verifier__get.side_effect = exceptions.ResourceNotFound(id="1")
+        mock___verifier__get.side_effect = exceptions.DBRecordNotFound(
+            criteria="uuid: 1", table="verifiers")
 
         name = "SomeVerifier"
         vtype = "fake_verifier"
@@ -1263,7 +1167,8 @@ class VerifierAPITestCase(test.TestCase):
     def test_create_fails_on_install_step(
             self, mock_verifier_manager_get, mock___verifier__get,
             mock_verifier_create):
-        mock___verifier__get.side_effect = exceptions.ResourceNotFound(id="1")
+        mock___verifier__get.side_effect = exceptions.DBRecordNotFound(
+            criteria="id: 1", table="verifiers")
         verifier_obj = mock_verifier_create.return_value
         verifier_obj.manager.install.side_effect = RuntimeError
 
@@ -1312,10 +1217,10 @@ class VerifierAPITestCase(test.TestCase):
         self.assertFalse(mock_verifier_delete.called)
         self.verifier_inst.api.verification.list.assert_called_once_with(
             verifier_id=verifier_id, deployment_id=deployment_id)
-        verifier_obj.set_deployment.assert_called_once_with(deployment_id)
+        verifier_obj.set_env.assert_called_once_with(deployment_id)
         verifier_obj.manager.uninstall.assert_called_once_with()
 
-        verifier_obj.set_deployment.reset_mock()
+        verifier_obj.set_env.reset_mock()
         verifier_obj.manager.uninstall.reset_mock()
 
         self.verifier_inst.api.verification.list.reset_mock()
@@ -1325,7 +1230,7 @@ class VerifierAPITestCase(test.TestCase):
 
         self.verifier_inst.api.verification.list.assert_called_once_with(
             verifier_id=verifier_id, deployment_id=None)
-        self.assertFalse(verifier_obj.set_deployment.called)
+        self.assertFalse(verifier_obj.set_env.called)
         verifier_obj.manager.uninstall.assert_called_once_with(full=True)
         mock_verifier_delete.assert_called_once_with(verifier_id)
 
@@ -1852,7 +1757,7 @@ class VerificationAPITestCase(test.TestCase):
             results["totals"])
         self.verification_inst.api.verifier._get.assert_called_once_with(
             verifier_id)
-        verifier_obj.set_deployment.assert_called_once_with(deployment_id)
+        verifier_obj.set_env.assert_called_once_with(deployment_id)
         verifier_obj.manager.validate_args.assert_called_once_with(run_args)
         mock_verification_create.assert_called_once_with(
             verifier_id, deployment_id=deployment_id, run_args=run_args)
@@ -1920,7 +1825,7 @@ class VerificationAPITestCase(test.TestCase):
         self.verification_inst.start(verifier_id=verifier_id,
                                      deployment_id=deployment_id)
         mock_deployment_get.assert_called_once_with(deployment_id)
-        verifier_obj.set_deployment.assert_called_once_with(deployment_id)
+        verifier_obj.set_env.assert_called_once_with(deployment_id)
 
     @mock.patch("rally.api.objects.Verification.create")
     @mock.patch("rally.api._Verifier.configure")
@@ -1947,7 +1852,7 @@ class VerificationAPITestCase(test.TestCase):
                                      **run_args)
 
         mock_deployment_get.assert_called_once_with(deployment_id)
-        verifier_obj.set_deployment.assert_called_once_with(deployment_id)
+        verifier_obj.set_env.assert_called_once_with(deployment_id)
         verifier_obj.manager.validate.assert_called_once_with(run_args)
 
         mock_verification_create.assert_called_once_with(
@@ -2011,7 +1916,7 @@ class VerificationAPITestCase(test.TestCase):
                           deployment_id=deployment_id,
                           tags=tags, **run_args)
 
-        verifier_obj.set_deployment.assert_called_once_with(deployment_id)
+        verifier_obj.set_env.assert_called_once_with(deployment_id)
         verifier_obj.manager.validate.assert_called_once_with(run_args)
         mock_verification_create.assert_called_once_with(
             verifier_id=verifier_id, deployment_id=deployment_id, tags=tags,
